'''
Manage filters associated with feature flags stored in an App Configuration.
'''
from .... pyaz_utils import _call_az

def add(filter_name, auth_mode=None, connection_string=None, endpoint=None, feature=None, filter_parameters=None, index=None, key=None, label=None, name=None, yes=None):
    '''
    Add a filter to a feature flag.

    Required Parameters:
    - filter_name -- Name of the filter to be added.

    Optional Parameters:
    - auth_mode -- This parameter can be used for indicating how a data operation is to be authorized. If the auth mode is "key", provide connection string or store name and your account access keys will be retrieved for authorization. If the auth mode is "login", provide the store endpoint or store name and your "az login" credentials will be used for authorization. You can configure the default auth mode using `az configure --defaults appconfig_auth_mode=<auth_mode>`. For more information, see https://docs.microsoft.com/azure/azure-app-configuration/concept-enable-rbac
    - connection_string -- Combination of access key and endpoint of App Configuration. Can be found using 'az appconfig credential list'. Users can preset it using `az configure --defaults appconfig_connection_string=<connection_string>` or environment variable with the name AZURE_APPCONFIG_CONNECTION_STRING.
    - endpoint -- If auth mode is "login", provide endpoint URL of the App Configuration. The endpoint can be retrieved using "az appconfig show" command. You can configure the default endpoint using `az configure --defaults appconfig_endpoint=<endpoint>`
    - feature -- Name of the feature to which you want to add the filter. If the feature flag key is different from the default key, provide the `--key` argument instead.
    - filter_parameters -- Space-separated filter parameters in 'name[=value]' format. The value must be an escaped JSON string.
    - index -- Zero-based index in the list of filters where you want to insert the new filter. If no index is specified or index is invalid, filter will be added to the end of the list.
    - key -- Key of the feature flag. Key must start with the ".appconfig.featureflag/" prefix. Key cannot contain the "%" character. If both key and feature arguments are provided, only key will be used. Default key is the reserved prefix ".appconfig.featureflag/" + feature name.
    - label -- If no label specified, add to the feature flag with null label by default.
    - name -- Name of the App Configuration. You can configure the default name using `az configure --defaults app_configuration_store=<name>`
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az appconfig feature filter add", locals())


def delete(all=None, auth_mode=None, connection_string=None, endpoint=None, feature=None, filter_name=None, index=None, key=None, label=None, name=None, yes=None):
    '''
    Delete a filter from a feature flag.

    Optional Parameters:
    - all -- Delete all filters associated with a feature flag.
    - auth_mode -- This parameter can be used for indicating how a data operation is to be authorized. If the auth mode is "key", provide connection string or store name and your account access keys will be retrieved for authorization. If the auth mode is "login", provide the store endpoint or store name and your "az login" credentials will be used for authorization. You can configure the default auth mode using `az configure --defaults appconfig_auth_mode=<auth_mode>`. For more information, see https://docs.microsoft.com/azure/azure-app-configuration/concept-enable-rbac
    - connection_string -- Combination of access key and endpoint of App Configuration. Can be found using 'az appconfig credential list'. Users can preset it using `az configure --defaults appconfig_connection_string=<connection_string>` or environment variable with the name AZURE_APPCONFIG_CONNECTION_STRING.
    - endpoint -- If auth mode is "login", provide endpoint URL of the App Configuration. The endpoint can be retrieved using "az appconfig show" command. You can configure the default endpoint using `az configure --defaults appconfig_endpoint=<endpoint>`
    - feature -- Name of the feature from which you want to delete the filter. If the feature flag key is different from the default key, provide the `--key` argument instead.
    - filter_name -- Name of the filter to be deleted.
    - index -- Zero-based index of the filter to be deleted in case there are multiple instances with same filter name.
    - key -- Key of the feature flag. Key must start with the ".appconfig.featureflag/" prefix. Key cannot contain the "%" character. If both key and feature arguments are provided, only key will be used. Default key is the reserved prefix ".appconfig.featureflag/" + feature name.
    - label -- If no label specified, delete from the feature flag with null label by default.
    - name -- Name of the App Configuration. You can configure the default name using `az configure --defaults app_configuration_store=<name>`
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az appconfig feature filter delete", locals())


def show(filter_name, auth_mode=None, connection_string=None, endpoint=None, feature=None, index=None, key=None, label=None, name=None):
    '''
    Show filters of a feature flag.

    Required Parameters:
    - filter_name -- Name of the filter to be displayed.

    Optional Parameters:
    - auth_mode -- This parameter can be used for indicating how a data operation is to be authorized. If the auth mode is "key", provide connection string or store name and your account access keys will be retrieved for authorization. If the auth mode is "login", provide the store endpoint or store name and your "az login" credentials will be used for authorization. You can configure the default auth mode using `az configure --defaults appconfig_auth_mode=<auth_mode>`. For more information, see https://docs.microsoft.com/azure/azure-app-configuration/concept-enable-rbac
    - connection_string -- Combination of access key and endpoint of App Configuration. Can be found using 'az appconfig credential list'. Users can preset it using `az configure --defaults appconfig_connection_string=<connection_string>` or environment variable with the name AZURE_APPCONFIG_CONNECTION_STRING.
    - endpoint -- If auth mode is "login", provide endpoint URL of the App Configuration. The endpoint can be retrieved using "az appconfig show" command. You can configure the default endpoint using `az configure --defaults appconfig_endpoint=<endpoint>`
    - feature -- Name of the feature which contains the filter. If the feature flag key is different from the default key, provide the `--key` argument instead.
    - index -- Zero-based index of the filter to be displayed in case there are multiple instances with same filter name.
    - key -- Key of the feature flag. Key must start with the ".appconfig.featureflag/" prefix. Key cannot contain the "%" character. If both key and feature arguments are provided, only key will be used. Default key is the reserved prefix ".appconfig.featureflag/" + feature name.
    - label -- If no label specified, show the feature flag with null label by default.
    - name -- Name of the App Configuration. You can configure the default name using `az configure --defaults app_configuration_store=<name>`
    '''
    return _call_az("az appconfig feature filter show", locals())


def list(all=None, auth_mode=None, connection_string=None, endpoint=None, feature=None, key=None, label=None, name=None, top=None):
    '''
    List all filters for a feature flag.

    Optional Parameters:
    - all -- List all filters associated with a feature flag.
    - auth_mode -- This parameter can be used for indicating how a data operation is to be authorized. If the auth mode is "key", provide connection string or store name and your account access keys will be retrieved for authorization. If the auth mode is "login", provide the store endpoint or store name and your "az login" credentials will be used for authorization. You can configure the default auth mode using `az configure --defaults appconfig_auth_mode=<auth_mode>`. For more information, see https://docs.microsoft.com/azure/azure-app-configuration/concept-enable-rbac
    - connection_string -- Combination of access key and endpoint of App Configuration. Can be found using 'az appconfig credential list'. Users can preset it using `az configure --defaults appconfig_connection_string=<connection_string>` or environment variable with the name AZURE_APPCONFIG_CONNECTION_STRING.
    - endpoint -- If auth mode is "login", provide endpoint URL of the App Configuration. The endpoint can be retrieved using "az appconfig show" command. You can configure the default endpoint using `az configure --defaults appconfig_endpoint=<endpoint>`
    - feature -- Name of the feature whose filters you want to be displayed. If the feature flag key is different from the default key, provide the `--key` argument instead.
    - key -- Key of the feature flag. Key must start with the ".appconfig.featureflag/" prefix. Key cannot contain the "%" character. If both key and feature arguments are provided, only key will be used. Default key is the reserved prefix ".appconfig.featureflag/" + feature name.
    - label -- If no label specified, display filters from the feature flag with null label by default.
    - name -- Name of the App Configuration. You can configure the default name using `az configure --defaults app_configuration_store=<name>`
    - top -- Maximum number of items to return. Must be a positive integer. Default to 100.
    '''
    return _call_az("az appconfig feature filter list", locals())




from ... pyaz_utils import _call_az

def show(name, resource_group):
    '''
    Show the details of an action group

    Required Parameters:
    - name -- The name of the action group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az monitor action-group show", locals())


def create(name, resource_group, action=None, short_name=None, tags=None):
    '''
    Create a new action group

    Required Parameters:
    - name -- The name of the action group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - action -- None
    - short_name -- None
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az monitor action-group create", locals())


def delete(name, resource_group):
    '''
    

    Required Parameters:
    - name -- The name of the action group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az monitor action-group delete", locals())


def enable_receiver(action_group, name, resource_group):
    '''
    Enable a receiver in an action group.

    Required Parameters:
    - action_group -- The name of the action group.
    - name -- The name of the receiver to resubscribe.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az monitor action-group enable-receiver", locals())


def list(resource_group=None):
    '''
    List action groups under a resource group or the current subscription

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az monitor action-group list", locals())


def update(name, resource_group, add=None, add_action=None, force_string=None, remove=None, remove_action=None, set=None, short_name=None, tags=None):
    '''
    Update an action group

    Required Parameters:
    - name -- The name of the action group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - add_action -- None
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - remove_action -- None
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - short_name -- None
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az monitor action-group update", locals())




'''
A backup policy defines when you want to take a backup and for how long you would retain each backup copy.
'''
from ... pyaz_utils import _call_az

def get_default_for_vm(resource_group, vault_name):
    '''
    Get the default policy with default values to backup a VM.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vault_name -- Name of the Recovery services vault.
    '''
    return _call_az("az backup policy get-default-for-vm", locals())


def show(name, resource_group, vault_name):
    '''
    Show details of a particular policy.

    Required Parameters:
    - name -- Name of the backup policy. You can use the backup policy list command to get the name of a policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vault_name -- Name of the Recovery services vault.
    '''
    return _call_az("az backup policy show", locals())


def list(resource_group, vault_name, backup_management_type=None, workload_type=None):
    '''
    List all policies for a Recovery services vault.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vault_name -- Name of the Recovery services vault.

    Optional Parameters:
    - backup_management_type -- Specify the backup management type. Define how Azure Backup manages the backup of entities within the ARM resource. For eg: AzureWorkloads refers to workloads installed within Azure VMs, AzureStorage refers to entities within Storage account. Required only if friendly name is used as Container name.
    - workload_type -- Specify the type of applications within the Resource which should be discovered and protected by Azure Backup. 
    '''
    return _call_az("az backup policy list", locals())


def list_associated_items(name, resource_group, vault_name, backup_management_type=None):
    '''
    List all items protected by a backup policy.

    Required Parameters:
    - name -- Name of the backup policy. You can use the backup policy list command to get the name of a policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vault_name -- Name of the Recovery services vault.

    Optional Parameters:
    - backup_management_type -- Specify the backup management type. Define how Azure Backup manages the backup of entities within the ARM resource. For eg: AzureWorkloads refers to workloads installed within Azure VMs, AzureStorage refers to entities within Storage account. Required only if friendly name is used as Container name.
    '''
    return _call_az("az backup policy list-associated-items", locals())


def set(resource_group, vault_name, backup_management_type=None, fix_for_inconsistent_items=None, name=None, policy=None):
    '''
    Update the existing policy with the provided details.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vault_name -- Name of the Recovery services vault.

    Optional Parameters:
    - backup_management_type -- Specify the backup management type. Define how Azure Backup manages the backup of entities within the ARM resource. For eg: AzureWorkloads refers to workloads installed within Azure VMs, AzureStorage refers to entities within Storage account. Required only if friendly name is used as Container name.
    - fix_for_inconsistent_items -- Specify whether or not to retry Policy Update for failed items.
    - name -- Name of the Policy.
    - policy -- JSON encoded policy definition. Use the show command with JSON output to obtain a policy object. Modify the values using a file editor and pass the object.
    '''
    return _call_az("az backup policy set", locals())


def delete(name, resource_group, vault_name):
    '''
    Delete a backup policy which doesn't have any associated backup items.

    Required Parameters:
    - name -- Name of the backup policy. You can use the backup policy list command to get the name of a policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vault_name -- Name of the Recovery services vault.
    '''
    return _call_az("az backup policy delete", locals())


def create(backup_management_type, name, policy, resource_group, vault_name, workload_type=None):
    '''
    Create a new policy for the given BackupManagementType and workloadType.

    Required Parameters:
    - backup_management_type -- Specify the backup management type. Define how Azure Backup manages the backup of entities within the ARM resource. For eg: AzureWorkloads refers to workloads installed within Azure VMs, AzureStorage refers to entities within Storage account. Required only if friendly name is used as Container name.
    - name -- Name of the Policy.
    - policy -- JSON encoded policy definition. Use the show command with JSON output to obtain a policy object. Modify the values using a file editor and pass the object.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vault_name -- Name of the Recovery services vault.

    Optional Parameters:
    - workload_type -- Specify the type of applications within the Resource which should be discovered and protected by Azure Backup. 
    '''
    return _call_az("az backup policy create", locals())




from .... pyaz_utils import _call_az

def list(resource_group, workspace_name):
    '''
    List all firewall rules.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse workspace firewall-rule list", locals())


def show(name, resource_group, workspace_name):
    '''
    Get a firewall rule.

    Required Parameters:
    - name -- The IP firewall rule name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse workspace firewall-rule show", locals())


def create(end_ip_address, name, resource_group, start_ip_address, workspace_name, no_wait=None):
    '''
    Create a firewall rule.

    Required Parameters:
    - end_ip_address -- The end IP address of the firewall rule. Must be IPv4 format. Must be greater than or equal to startIpAddress.
    - name -- The IP firewall rule name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - start_ip_address -- The start IP address of the firewall rule. Must be IPv4 format.
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az synapse workspace firewall-rule create", locals())


def update(name, resource_group, workspace_name, end_ip_address=None, no_wait=None, start_ip_address=None):
    '''
    Update a firewall rule.

    Required Parameters:
    - name -- The IP firewall rule name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.

    Optional Parameters:
    - end_ip_address -- The end IP address of the firewall rule. Must be IPv4 format. Must be greater than or equal to startIpAddress.
    - no_wait -- Do not wait for the long-running operation to finish.
    - start_ip_address -- The start IP address of the firewall rule. Must be IPv4 format.
    '''
    return _call_az("az synapse workspace firewall-rule update", locals())


def delete(name, resource_group, workspace_name, no_wait=None, yes=None):
    '''
    Delete a firewall rule.

    Required Parameters:
    - name -- The IP firewall rule name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az synapse workspace firewall-rule delete", locals())


def wait(resource_group, rule_name, workspace_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of a firewall rule is met.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rule_name -- The IP firewall rule name.
    - workspace_name -- The workspace name.

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az synapse workspace firewall-rule wait", locals())




from .... pyaz_utils import _call_az

def list(gateway_name, resource_group):
    '''
    List HTTP listeners.

    Required Parameters:
    - gateway_name -- The name of the application gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway http-listener list", locals())


def show(gateway_name, name, resource_group):
    '''
    Get the details of an HTTP listener.

    Required Parameters:
    - gateway_name -- The name of the application gateway.
    - name -- The name of the HTTP listener.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway http-listener show", locals())


def delete(gateway_name, name, resource_group, no_wait=None):
    '''
    Delete an HTTP listener.

    Required Parameters:
    - gateway_name -- The name of the application gateway.
    - name -- The name of the HTTP listener.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az network application-gateway http-listener delete", locals())


def create(frontend_port, gateway_name, name, resource_group, frontend_ip=None, host_name=None, host_names=None, no_wait=None, ssl_cert=None, ssl_profile_id=None, waf_policy=None):
    '''
    Create an HTTP listener.

    Required Parameters:
    - frontend_port -- The name or ID of the frontend port.
    - gateway_name -- Name of the application gateway.
    - name -- The name of the HTTP listener.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - frontend_ip -- The name or ID of the frontend IP configuration. If only one exists, omit to use as default.
    - host_name -- Host name to use for multisite gateways.
    - host_names -- Space-separated list of host names that allows special wildcard characters as well.
    - no_wait -- Do not wait for the long-running operation to finish.
    - ssl_cert -- The name or ID of the SSL certificate to use.
    - ssl_profile_id -- SSL profile resource of the application gateway.
    - waf_policy -- Name or ID of a Firewall Policy resource.
    '''
    return _call_az("az network application-gateway http-listener create", locals())


def update(gateway_name, name, resource_group, add=None, force_string=None, frontend_ip=None, frontend_port=None, host_name=None, host_names=None, no_wait=None, remove=None, set=None, ssl_cert=None, ssl_profile_id=None, waf_policy=None):
    '''
    Update an HTTP listener.

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - name -- The name of the HTTP listener.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - frontend_ip -- The name or ID of the frontend IP configuration.
    - frontend_port -- The name or ID of the frontend port.
    - host_name -- Host name to use for multisite gateways.
    - host_names -- Space-separated list of host names that allows special wildcard characters as well.
    - no_wait -- Do not wait for the long-running operation to finish.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - ssl_cert -- The name or ID of the SSL certificate to use.
    - ssl_profile_id -- SSL profile resource of the application gateway.
    - waf_policy -- Name or ID of a Firewall Policy resource.
    '''
    return _call_az("az network application-gateway http-listener update", locals())




from ... pyaz_utils import _call_az
from . import prefix


def delete(name, resource_group):
    '''
    Delete a public IP address.

    Required Parameters:
    - name -- The name of the public IP address.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network public-ip delete", locals())


def show(name, resource_group, expand=None):
    '''
    Get the details of a public IP address.

    Required Parameters:
    - name -- The name of the public IP address.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - expand -- Expands referenced resources.
    '''
    return _call_az("az network public-ip show", locals())


def list(resource_group=None):
    '''
    List public IP addresses.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network public-ip list", locals())


def create(name, resource_group, allocation_method=None, dns_name=None, edge_zone=None, idle_timeout=None, ip_address=None, ip_tags=None, location=None, public_ip_prefix=None, reverse_fqdn=None, sku=None, tags=None, tier=None, version=None, zone=None):
    '''
    Create a public IP address.

    Required Parameters:
    - name -- The name of the public IP address.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - allocation_method -- IP address allocation method
    - dns_name -- Globally unique DNS entry.
    - edge_zone -- The name of edge zone.
    - idle_timeout -- Idle timeout in minutes.
    - ip_address -- The IP address associated with the public IP address resource.
    - ip_tags -- Space-separated list of IP tags in 'TYPE=VAL' format.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - public_ip_prefix -- Name or ID of a public IP prefix.
    - reverse_fqdn -- Reverse FQDN (fully qualified domain name).
    - sku -- Name of a public IP address SKU
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - tier -- Tier of a public IP address SKU and Global tier is only supported for standard SKU public IP addresses
    - version -- IP address type.
    - zone -- Space-separated list of availability zones into which to provision the resource.
    '''
    return _call_az("az network public-ip create", locals())


def update(name, resource_group, add=None, allocation_method=None, dns_name=None, force_string=None, idle_timeout=None, ip_tags=None, public_ip_prefix=None, remove=None, reverse_fqdn=None, set=None, sku=None, tags=None, version=None):
    '''
    Update a public IP address.

    Required Parameters:
    - name -- The name of the public IP address.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - allocation_method -- IP address allocation method
    - dns_name -- Globally unique DNS entry.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - idle_timeout -- Idle timeout in minutes.
    - ip_tags -- Space-separated list of IP tags in 'TYPE=VAL' format.
    - public_ip_prefix -- Name or ID of a public IP prefix.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - reverse_fqdn -- Reverse FQDN (fully qualified domain name).
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - sku -- Public IP SKU
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - version -- IP address type.
    '''
    return _call_az("az network public-ip update", locals())




from ... pyaz_utils import _call_az
from . import correlation_scheme, load_metrics


def list(application, cluster_name, resource_group):
    '''
    List managed services of a given managed application.

    Required Parameters:
    - application -- Specify the name of the service.
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sf managed-service list", locals())


def delete(application, cluster_name, name, resource_group):
    '''
    Delete a managed service.

    Required Parameters:
    - application -- Specify the name of the service.
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - name -- Specify the name of the service.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sf managed-service delete", locals())


def show(application, cluster_name, name, resource_group):
    '''
    Get a service.

    Required Parameters:
    - application -- Specify the name of the service.
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - name -- Specify the name of the service.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sf managed-service show", locals())


def create(application, cluster_name, name, resource_group, state, type, default_move_cost=None, has_persisted_state=None, high_key=None, instance_count=None, low_key=None, min_instance_count=None, min_instance_percentage=None, min_replica_set_size=None, partition_count=None, partition_names=None, partition_scheme=None, placement_constraints=None, quorum_loss_wait_duration=None, replica_restart_wait_duration=None, service_package_activation_mode=None, service_placement_time_limit=None, stand_by_replica_keep_duration=None, tags=None, target_replica_set_size=None):
    '''
    Create a new managed service on an Azure Service Fabric managed cluster.

    Required Parameters:
    - application -- Specify the name of the service.
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - name -- Specify the name of the service.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    - state -- Specify if the service is stateless or stateful.
    - type -- Specify the service type name of the application, it should exist in the application manifest.

    Optional Parameters:
    - default_move_cost -- Specify the default cost for a move. Higher costs make it less likely that the Cluster Resource Manager will move the replica when trying to balance the cluster.
    - has_persisted_state -- Determines whether this is a persistent service which stores states on the local disk. If it is then the value of this property is true, if not it is false.
    - high_key -- Specify the upper bound of the partition key range that should be split between the partition ‘Count’ This is only used with UniformInt64 partition scheme.
    - instance_count -- Specify the instance count for the stateless service. If -1 is used, it means it will run on all the nodes.
    - low_key -- Specify the lower bound of the partition key range that should be split between the partition ‘Count’ This is only used with UniformInt64 partition scheme.
    - min_instance_count -- Specify the minimum number of instances that must be up to meet the EnsureAvailability safety check during operations like upgrade or deactivate node. The actual number that is used is max( MinInstanceCount, ceil( MinInstancePercentage/100.0 * InstanceCount) ). Note, if InstanceCount is set to -1, during MinInstanceCount computation -1 is first converted into the number of nodes on which the instances are allowed to be placed according to the placement constraints on the service.
    - min_instance_percentage -- Specify the minimum percentage of InstanceCount that must be up to meet the EnsureAvailability safety check during operations like upgrade or deactivate node. The actual number that is used is max( MinInstanceCount, ceil( MinInstancePercentage/100.0 * InstanceCount) ). Note, if InstanceCount is set to -1, during MinInstancePercentage computation, -1 is first converted into the number of nodes on which the instances are allowed to be placed according to the placement constraints on the service. Allowed values are from 0 to 100.
    - min_replica_set_size -- Specify the min replica set size for the stateful service.
    - partition_count -- Specify the number of partitions. This is only used with UniformInt64 partition scheme.
    - partition_names -- Specify the array for the names of the partitions. This is only used with Named partition scheme.
    - partition_scheme -- Specify what partition scheme to use. Singleton partitions are typically used when the service does not require any additional routing. UniformInt64 means that each partition owns a range of int64 keys. Named is usually for services with data that can be bucketed, within a bounded set. Some common examples of data fields used as named partition keys would be regions, postal codes, customer groups, or other business boundaries.
    - placement_constraints -- Specify the placement constraints as a string. Placement constraints are boolean expressions on node properties and allow for restricting a service to particular nodes based on the service requirements. For example, to place a service on nodes where NodeType is blue specify the following: "NodeColor == blue)".
    - quorum_loss_wait_duration -- Specify the maximum duration for which a partition is allowed to be in a state of quorum loss, represented in ISO 8601 format "hh:mm:ss".
    - replica_restart_wait_duration -- Specify the duration between when a replica goes down and when a new replica is created, represented in ISO 8601 format "hh:mm:ss".
    - service_package_activation_mode -- Specify the activation mode of the service package.
    - service_placement_time_limit -- Specify the duration for which replicas can stay InBuild before reporting that build is stuck, represented in ISO 8601 format "hh:mm:ss".
    - stand_by_replica_keep_duration -- Specify the definition on how long StandBy replicas should be maintained before being removed, represented in ISO 8601 format "hh:mm:ss".
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - target_replica_set_size -- Specify the target replica set size for the stateful service.
    '''
    return _call_az("az sf managed-service create", locals())


def update(application, cluster_name, name, resource_group, default_move_cost=None, instance_count=None, min_instance_count=None, min_instance_percentage=None, min_replica_set_size=None, placement_constraints=None, quorum_loss_wait_duration=None, replica_restart_wait_duration=None, service_placement_time_limit=None, stand_by_replica_keep_duration=None, tags=None, target_replica_set_size=None):
    '''
    Update a managed service.

    Required Parameters:
    - application -- Specify the name of the service.
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - name -- Specify the name of the service.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - default_move_cost -- Specify the default cost for a move. Higher costs make it less likely that the Cluster Resource Manager will move the replica when trying to balance the cluster.
    - instance_count -- Specify the instance count for the stateless service. If -1 is used, it means it will run on all the nodes.
    - min_instance_count -- Specify the minimum number of instances that must be up to meet the EnsureAvailability safety check during operations like upgrade or deactivate node. The actual number that is used is max( MinInstanceCount, ceil( MinInstancePercentage/100.0 * InstanceCount) ). Note, if InstanceCount is set to -1, during MinInstanceCount computation -1 is first converted into the number of nodes on which the instances are allowed to be placed according to the placement constraints on the service.
    - min_instance_percentage -- Specify the minimum percentage of InstanceCount that must be up to meet the EnsureAvailability safety check during operations like upgrade or deactivate node. The actual number that is used is max( MinInstanceCount, ceil( MinInstancePercentage/100.0 * InstanceCount) ). Note, if InstanceCount is set to -1, during MinInstancePercentage computation, -1 is first converted into the number of nodes on which the instances are allowed to be placed according to the placement constraints on the service. Allowed values are from 0 to 100.
    - min_replica_set_size -- Specify the min replica set size for the stateful service.
    - placement_constraints -- Specify the placement constraints as a string. Placement constraints are boolean expressions on node properties and allow for restricting a service to particular nodes based on the service requirements. For example, to place a service on nodes where NodeType is blue specify the following: "NodeColor == blue)".
    - quorum_loss_wait_duration -- Specify the maximum duration for which a partition is allowed to be in a state of quorum loss, represented in ISO 8601 format "hh:mm:ss".
    - replica_restart_wait_duration -- Specify the duration between when a replica goes down and when a new replica is created, represented in ISO 8601 format "hh:mm:ss".
    - service_placement_time_limit -- Specify the duration for which replicas can stay InBuild before reporting that build is stuck, represented in ISO 8601 format "hh:mm:ss".
    - stand_by_replica_keep_duration -- Specify the definition on how long StandBy replicas should be maintained before being removed, represented in ISO 8601 format "hh:mm:ss".
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - target_replica_set_size -- Specify the target replica set size for the stateful service.
    '''
    return _call_az("az sf managed-service update", locals())




'''
Update a webapp connection
'''
from .... pyaz_utils import _call_az

def postgres(client_type=None, connection=None, id=None, name=None, no_wait=None, resource_group=None, secret=None):
    '''
    Update a webapp to postgres connection.

    Optional Parameters:
    - client_type -- The client type used on the webapp
    - connection -- Name of the webapp connection.
    - id -- The resource id of the connection. ['--resource-group', '--name', '--connection'] are required if '--id' is not specified.
    - name -- Name of the webapp. Required if '--source-id' is not specified.
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- The resource group which contains the webapp. Required if '--source-id' is not specified.
    - secret -- The secret auth info
    '''
    return _call_az("az webapp connection update postgres", locals())


def postgres_flexible(client_type=None, connection=None, id=None, name=None, no_wait=None, resource_group=None, secret=None):
    '''
    Update a webapp to postgres-flexible connection.

    Optional Parameters:
    - client_type -- The client type used on the webapp
    - connection -- Name of the webapp connection.
    - id -- The resource id of the connection. ['--resource-group', '--name', '--connection'] are required if '--id' is not specified.
    - name -- Name of the webapp. Required if '--source-id' is not specified.
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- The resource group which contains the webapp. Required if '--source-id' is not specified.
    - secret -- The secret auth info
    '''
    return _call_az("az webapp connection update postgres-flexible", locals())


def mysql(client_type=None, connection=None, id=None, name=None, no_wait=None, resource_group=None, secret=None):
    '''
    Update a webapp to mysql connection.

    Optional Parameters:
    - client_type -- The client type used on the webapp
    - connection -- Name of the webapp connection.
    - id -- The resource id of the connection. ['--resource-group', '--name', '--connection'] are required if '--id' is not specified.
    - name -- Name of the webapp. Required if '--source-id' is not specified.
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- The resource group which contains the webapp. Required if '--source-id' is not specified.
    - secret -- The secret auth info
    '''
    return _call_az("az webapp connection update mysql", locals())


def mysql_flexible(client_type=None, connection=None, id=None, name=None, no_wait=None, resource_group=None, secret=None):
    '''
    Update a webapp to mysql-flexible connection.

    Optional Parameters:
    - client_type -- The client type used on the webapp
    - connection -- Name of the webapp connection.
    - id -- The resource id of the connection. ['--resource-group', '--name', '--connection'] are required if '--id' is not specified.
    - name -- Name of the webapp. Required if '--source-id' is not specified.
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- The resource group which contains the webapp. Required if '--source-id' is not specified.
    - secret -- The secret auth info
    '''
    return _call_az("az webapp connection update mysql-flexible", locals())


def cosmos_cassandra(client_type=None, connection=None, id=None, name=None, no_wait=None, resource_group=None, secret=None, service_principal=None, system_identity=None, user_identity=None):
    '''
    Update a webapp to cosmos-cassandra connection.

    Optional Parameters:
    - client_type -- The client type used on the webapp
    - connection -- Name of the webapp connection.
    - id -- The resource id of the connection. ['--resource-group', '--name', '--connection'] are required if '--id' is not specified.
    - name -- Name of the webapp. Required if '--source-id' is not specified.
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- The resource group which contains the webapp. Required if '--source-id' is not specified.
    - secret -- The secret auth info
    - service_principal -- The service principal auth info
    - system_identity -- The system assigned identity auth info
    - user_identity -- The user assigned identity auth info
    '''
    return _call_az("az webapp connection update cosmos-cassandra", locals())


def cosmos_gremlin(client_type=None, connection=None, id=None, name=None, no_wait=None, resource_group=None, secret=None, service_principal=None, system_identity=None, user_identity=None):
    '''
    Update a webapp to cosmos-gremlin connection.

    Optional Parameters:
    - client_type -- The client type used on the webapp
    - connection -- Name of the webapp connection.
    - id -- The resource id of the connection. ['--resource-group', '--name', '--connection'] are required if '--id' is not specified.
    - name -- Name of the webapp. Required if '--source-id' is not specified.
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- The resource group which contains the webapp. Required if '--source-id' is not specified.
    - secret -- The secret auth info
    - service_principal -- The service principal auth info
    - system_identity -- The system assigned identity auth info
    - user_identity -- The user assigned identity auth info
    '''
    return _call_az("az webapp connection update cosmos-gremlin", locals())


def cosmos_mongo(client_type=None, connection=None, id=None, name=None, no_wait=None, resource_group=None, secret=None, service_principal=None, system_identity=None, user_identity=None):
    '''
    Update a webapp to cosmos-mongo connection.

    Optional Parameters:
    - client_type -- The client type used on the webapp
    - connection -- Name of the webapp connection.
    - id -- The resource id of the connection. ['--resource-group', '--name', '--connection'] are required if '--id' is not specified.
    - name -- Name of the webapp. Required if '--source-id' is not specified.
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- The resource group which contains the webapp. Required if '--source-id' is not specified.
    - secret -- The secret auth info
    - service_principal -- The service principal auth info
    - system_identity -- The system assigned identity auth info
    - user_identity -- The user assigned identity auth info
    '''
    return _call_az("az webapp connection update cosmos-mongo", locals())


def cosmos_table(client_type=None, connection=None, id=None, name=None, no_wait=None, resource_group=None, secret=None, service_principal=None, system_identity=None, user_identity=None):
    '''
    Update a webapp to cosmos-table connection.

    Optional Parameters:
    - client_type -- The client type used on the webapp
    - connection -- Name of the webapp connection.
    - id -- The resource id of the connection. ['--resource-group', '--name', '--connection'] are required if '--id' is not specified.
    - name -- Name of the webapp. Required if '--source-id' is not specified.
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- The resource group which contains the webapp. Required if '--source-id' is not specified.
    - secret -- The secret auth info
    - service_principal -- The service principal auth info
    - system_identity -- The system assigned identity auth info
    - user_identity -- The user assigned identity auth info
    '''
    return _call_az("az webapp connection update cosmos-table", locals())


def cosmos_sql(client_type=None, connection=None, id=None, name=None, no_wait=None, resource_group=None, secret=None, service_principal=None, system_identity=None, user_identity=None):
    '''
    Update a webapp to cosmos-sql connection.

    Optional Parameters:
    - client_type -- The client type used on the webapp
    - connection -- Name of the webapp connection.
    - id -- The resource id of the connection. ['--resource-group', '--name', '--connection'] are required if '--id' is not specified.
    - name -- Name of the webapp. Required if '--source-id' is not specified.
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- The resource group which contains the webapp. Required if '--source-id' is not specified.
    - secret -- The secret auth info
    - service_principal -- The service principal auth info
    - system_identity -- The system assigned identity auth info
    - user_identity -- The user assigned identity auth info
    '''
    return _call_az("az webapp connection update cosmos-sql", locals())


def storage_blob(client_type=None, connection=None, id=None, name=None, no_wait=None, resource_group=None, secret=None, service_principal=None, system_identity=None, user_identity=None):
    '''
    Update a webapp to storage-blob connection.

    Optional Parameters:
    - client_type -- The client type used on the webapp
    - connection -- Name of the webapp connection.
    - id -- The resource id of the connection. ['--resource-group', '--name', '--connection'] are required if '--id' is not specified.
    - name -- Name of the webapp. Required if '--source-id' is not specified.
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- The resource group which contains the webapp. Required if '--source-id' is not specified.
    - secret -- The secret auth info
    - service_principal -- The service principal auth info
    - system_identity -- The system assigned identity auth info
    - user_identity -- The user assigned identity auth info
    '''
    return _call_az("az webapp connection update storage-blob", locals())


def storage_queue(client_type=None, connection=None, id=None, name=None, no_wait=None, resource_group=None, secret=None, service_principal=None, system_identity=None, user_identity=None):
    '''
    Update a webapp to storage-queue connection.

    Optional Parameters:
    - client_type -- The client type used on the webapp
    - connection -- Name of the webapp connection.
    - id -- The resource id of the connection. ['--resource-group', '--name', '--connection'] are required if '--id' is not specified.
    - name -- Name of the webapp. Required if '--source-id' is not specified.
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- The resource group which contains the webapp. Required if '--source-id' is not specified.
    - secret -- The secret auth info
    - service_principal -- The service principal auth info
    - system_identity -- The system assigned identity auth info
    - user_identity -- The user assigned identity auth info
    '''
    return _call_az("az webapp connection update storage-queue", locals())


def storage_file(client_type=None, connection=None, id=None, name=None, no_wait=None, resource_group=None, secret=None):
    '''
    Update a webapp to storage-file connection.

    Optional Parameters:
    - client_type -- The client type used on the webapp
    - connection -- Name of the webapp connection.
    - id -- The resource id of the connection. ['--resource-group', '--name', '--connection'] are required if '--id' is not specified.
    - name -- Name of the webapp. Required if '--source-id' is not specified.
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- The resource group which contains the webapp. Required if '--source-id' is not specified.
    - secret -- The secret auth info
    '''
    return _call_az("az webapp connection update storage-file", locals())


def storage_table(client_type=None, connection=None, id=None, name=None, no_wait=None, resource_group=None, secret=None):
    '''
    Update a webapp to storage-table connection.

    Optional Parameters:
    - client_type -- The client type used on the webapp
    - connection -- Name of the webapp connection.
    - id -- The resource id of the connection. ['--resource-group', '--name', '--connection'] are required if '--id' is not specified.
    - name -- Name of the webapp. Required if '--source-id' is not specified.
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- The resource group which contains the webapp. Required if '--source-id' is not specified.
    - secret -- The secret auth info
    '''
    return _call_az("az webapp connection update storage-table", locals())


def keyvault(client_type=None, connection=None, id=None, name=None, no_wait=None, resource_group=None, service_principal=None, system_identity=None, user_identity=None):
    '''
    Update a webapp to keyvault connection.

    Optional Parameters:
    - client_type -- The client type used on the webapp
    - connection -- Name of the webapp connection.
    - id -- The resource id of the connection. ['--resource-group', '--name', '--connection'] are required if '--id' is not specified.
    - name -- Name of the webapp. Required if '--source-id' is not specified.
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- The resource group which contains the webapp. Required if '--source-id' is not specified.
    - service_principal -- The service principal auth info
    - system_identity -- The system assigned identity auth info
    - user_identity -- The user assigned identity auth info
    '''
    return _call_az("az webapp connection update keyvault", locals())


def signalr(client_type=None, connection=None, id=None, name=None, no_wait=None, resource_group=None, secret=None, service_principal=None, system_identity=None, user_identity=None):
    '''
    Update a webapp to signalr connection.

    Optional Parameters:
    - client_type -- The client type used on the webapp
    - connection -- Name of the webapp connection.
    - id -- The resource id of the connection. ['--resource-group', '--name', '--connection'] are required if '--id' is not specified.
    - name -- Name of the webapp. Required if '--source-id' is not specified.
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- The resource group which contains the webapp. Required if '--source-id' is not specified.
    - secret -- The secret auth info
    - service_principal -- The service principal auth info
    - system_identity -- The system assigned identity auth info
    - user_identity -- The user assigned identity auth info
    '''
    return _call_az("az webapp connection update signalr", locals())


def confluent_cloud(connection, bootstrap_server=None, client_type=None, kafka_key=None, kafka_secret=None, name=None, no_wait=None, resource_group=None, schema_key=None, schema_registry=None, schema_secret=None, source_id=None):
    '''
    Update a webapp to confluent-cloud connection.

    Required Parameters:
    - connection -- Name of the connection

    Optional Parameters:
    - bootstrap_server -- Kafka bootstrap server url
    - client_type -- The client type used on the webapp
    - kafka_key -- Kafka API-Key (key)
    - kafka_secret -- Kafka API-Key (secret)
    - name -- Name of the webapp. Required if '--source-id' is not specified.
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- The resource group which contains the webapp. Required if '--source-id' is not specified.
    - schema_key -- Schema registry API-Key (key)
    - schema_registry -- Schema registry url
    - schema_secret -- Schema registry API-Key (secret)
    - source_id -- The resource id of a webapp. Required if ['--resource-group', '--name'] are not specified.
    '''
    return _call_az("az webapp connection update confluent-cloud", locals())




from .... pyaz_utils import _call_az

def list(account_endpoint=None, account_key=None, account_name=None, filter=None):
    '''
    Lists all Virtual Machine Images supported by the Azure Batch service.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - filter -- An OData $filter clause. For more information on constructing this filter, see https://docs.microsoft.com/en-us/rest/api/batchservice/odata-filters-in-batch#list-support-images.
    '''
    return _call_az("az batch pool supported-images list", locals())




from ... pyaz_utils import _call_az
from . import ipsec_policy, packet_capture, shared_key


def create(name, resource_group, vnet_gateway1, authorization_key=None, egress_nat_rule=None, enable_bgp=None, express_route_circuit2=None, express_route_gateway_bypass=None, ingress_nat_rule=None, local_gateway2=None, location=None, routing_weight=None, shared_key=None, tags=None, use_policy_based_traffic_selectors=None, validate=None, vnet_gateway2=None):
    '''
    Create a VPN connection.

    Required Parameters:
    - name -- Connection name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vnet_gateway1 -- None

    Optional Parameters:
    - authorization_key -- None
    - egress_nat_rule -- List of egress NatRules.
    - enable_bgp -- None
    - express_route_circuit2 -- None
    - express_route_gateway_bypass -- Bypass ExpressRoute gateway for data forwarding.
    - ingress_nat_rule -- List of ingress NatRules.
    - local_gateway2 -- None
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - routing_weight -- Connection routing weight
    - shared_key -- Shared IPSec key.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - use_policy_based_traffic_selectors -- Enable policy-based traffic selectors.
    - validate -- None
    - vnet_gateway2 -- None
    '''
    return _call_az("az network vpn-connection create", locals())


def delete(name, resource_group):
    '''
    Delete a VPN connection.

    Required Parameters:
    - name -- Connection name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network vpn-connection delete", locals())


def show(name, resource_group):
    '''
    Get the details of a VPN connection.

    Required Parameters:
    - name -- Connection name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network vpn-connection show", locals())


def list(resource_group, vnet_gateway=None):
    '''
    List all VPN connections.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - vnet_gateway -- Name of the VNet gateway.
    '''
    return _call_az("az network vpn-connection list", locals())


def update(name, resource_group, add=None, enable_bgp=None, express_route_gateway_bypass=None, force_string=None, remove=None, routing_weight=None, set=None, shared_key=None, tags=None, use_policy_based_traffic_selectors=None):
    '''
    Update a VPN connection.

    Required Parameters:
    - name -- Connection name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - enable_bgp -- Enable BGP (Border Gateway Protocol)
    - express_route_gateway_bypass -- Bypass ExpressRoute gateway for data forwarding.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - routing_weight -- Connection routing weight
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - shared_key -- Shared IPSec key.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - use_policy_based_traffic_selectors -- Enable policy-based traffic selectors.
    '''
    return _call_az("az network vpn-connection update", locals())


def list_ike_sas(name, resource_group):
    '''
    List IKE Security Associations for a VPN connection.

    Required Parameters:
    - name -- Connection name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network vpn-connection list-ike-sas", locals())


def show_device_config_script(device_family, firmware_version, name, resource_group, vendor):
    '''
    Get a XML format representation for VPN connection device configuration script.

    Required Parameters:
    - device_family -- The device family for the vpn device.
    - firmware_version -- The firmware version for the vpn device.
    - name -- Connection name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vendor -- The vendor for the VPN device.
    '''
    return _call_az("az network vpn-connection show-device-config-script", locals())




import pathlib
from setuptools import setup, find_packages

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

# This call to setup() does all the work
setup(
    name="py-az-cli",
    version="0.1.6",
    description="Pythonic wrapper for az cli",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/py-az-cli/py-az-cli",
    author="David P. Moore",
    author_email="9993122+bigdatamoore@users.noreply.github.com",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.9",
    ],
    packages=find_packages(exclude=("tests",)),
    include_package_data=False,
)


from .... pyaz_utils import _call_az

def show(account, storage_account_name, resource_group=None):
    '''
    

    Required Parameters:
    - account -- Name of the Data Lake Analytics account.
    - storage_account_name -- Name of an existing storage account to link to.

    Optional Parameters:
    - resource_group -- If not specified, will attempt to discover the resource group for the specified Data Lake Analytics account.
    '''
    return _call_az("az dla account blob-storage show", locals())


def add(access_key, account, storage_account_name, resource_group=None, suffix=None):
    '''
    Links an Azure Storage account to the specified Data Lake Analytics account.

    Required Parameters:
    - access_key -- the access key associated with this Azure Storage account that will be used to connect to it
    - account -- Name of the Data Lake Analytics account.
    - storage_account_name -- Name of an existing storage account to link to.

    Optional Parameters:
    - resource_group -- If not specified, will attempt to discover the resource group for the specified Data Lake Analytics account.
    - suffix -- the optional suffix for the storage account
    '''
    return _call_az("az dla account blob-storage add", locals())


def update(access_key, account, storage_account_name, resource_group=None, suffix=None):
    '''
    Updates an Azure Storage account linked to the specified Data Lake Analytics account.

    Required Parameters:
    - access_key -- the access key associated with this Azure Storage account that will be used to connect to it
    - account -- Name of the Data Lake Analytics account.
    - storage_account_name -- Name of an existing storage account to link to.

    Optional Parameters:
    - resource_group -- If not specified, will attempt to discover the resource group for the specified Data Lake Analytics account.
    - suffix -- the optional suffix for the storage account
    '''
    return _call_az("az dla account blob-storage update", locals())


def delete(account, storage_account_name, resource_group=None):
    '''
    

    Required Parameters:
    - account -- Name of the Data Lake Analytics account.
    - storage_account_name -- Name of an existing storage account to link to.

    Optional Parameters:
    - resource_group -- If not specified, will attempt to discover the resource group for the specified Data Lake Analytics account.
    '''
    return _call_az("az dla account blob-storage delete", locals())


def list(account, count=None, filter=None, orderby=None, resource_group=None, select=None, skip=None, top=None):
    '''
    

    Required Parameters:
    - account -- Name of the Data Lake Analytics account.

    Optional Parameters:
    - count -- The Boolean value of true or false to request a count of the matching resources included with the resources in the response, e.g. Categories?$count=true.
    - filter -- The OData filter. Optional.
    - orderby -- OrderBy clause. One or more comma-separated expressions with an optional "asc" (the default) or "desc" depending on the order you'd like the values sorted, e.g. Categories?$orderby=CategoryName desc. Optional.
    - resource_group -- If not specified, will attempt to discover the resource group for the specified Data Lake Analytics account.
    - select -- OData Select statement. Limits the properties on each entry to just those requested, e.g. Categories?$select=CategoryName,Description. Optional.
    - skip -- The number of items to skip over before returning elements.
    - top -- Maximum number of items to return.
    '''
    return _call_az("az dla account blob-storage list", locals())




'''
billing property
'''
from ... pyaz_utils import _call_az

def show():
    '''
    Get the billing properties for a subscription. This operation is not supported for billing accounts with agreement type Enterprise Agreement.
    '''
    return _call_az("az billing property show", locals())


def update(cost_center=None):
    '''
    Update the billing property of a subscription. Currently, cost center can be updated. The operation is supported only for billing accounts with agreement type Microsoft Customer Agreement.

    Optional Parameters:
    - cost_center -- The cost center applied to the subscription.
    '''
    return _call_az("az billing property update", locals())




'''
Manage a SQL pool's transparent data encryption.
'''
from ..... pyaz_utils import _call_az

def set(name, resource_group, status, transparent_data_encryption_name, workspace_name):
    '''
    Set a SQL pool's transparent data encryption configuration.

    Required Parameters:
    - name -- The SQL pool name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - status -- Status of the transparent data encryption.
    - transparent_data_encryption_name -- Name of the transparent data encryption.
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse sql pool tde set", locals())


def show(name, resource_group, transparent_data_encryption_name, workspace_name):
    '''
    Get a SQL pool's transparent data encryption configuration.

    Required Parameters:
    - name -- The SQL pool name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - transparent_data_encryption_name -- Name of the transparent data encryption.
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse sql pool tde show", locals())




'''
Manage Dedicated Host Groups
'''
from .... pyaz_utils import _call_az

def show(name, resource_group):
    '''
    Get the details of a dedicated host group.

    Required Parameters:
    - name -- Name of the Dedicated Host Group
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az vm host group show", locals())


def get_instance_view(name, resource_group):
    '''
    Get instance view of a dedicated host group.

    Required Parameters:
    - name -- Name of the Dedicated Host Group
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az vm host group get-instance-view", locals())


def create(name, platform_fault_domain_count, resource_group, automatic_placement=None, location=None, tags=None, zone=None):
    '''
    Create a dedicated host group.

    Required Parameters:
    - name -- Name of the Dedicated Host Group
    - platform_fault_domain_count -- Number of fault domains that the host group can span.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - automatic_placement -- Specify whether virtual machines or virtual machine scale sets can be placed automatically on the dedicated host group. Automatic placement means resources are allocated on dedicated hosts, that are chosen by Azure, under the dedicated host group. The value is defaulted to false when not provided.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`. Otherwise, location will default to the resource group's location
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - zone -- Availability zone into which to provision the resource.
    '''
    return _call_az("az vm host group create", locals())


def list(resource_group=None):
    '''
    List dedicated host groups.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az vm host group list", locals())


def update(name, resource_group, add=None, force_string=None, remove=None, set=None):
    '''
    Update a dedicated host group.

    Required Parameters:
    - name -- Name of the Dedicated Host Group
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az vm host group update", locals())


def delete(name, resource_group, yes=None):
    '''
    

    Required Parameters:
    - name -- Name of the Dedicated Host Group
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az vm host group delete", locals())




from ... pyaz_utils import _call_az
from . import authorization_rule


def set(alias, namespace_name, partner_namespace, resource_group, alternate_name=None):
    '''
    Sets Service Bus Geo-Disaster Recovery Configuration Alias for the give Namespace

    Required Parameters:
    - alias -- Name of the Geo-Disaster Recovery Configuration Alias
    - namespace_name -- Name of Namespace
    - partner_namespace -- Name (if within the same resource group) or ARM Id of Primary/Secondary Service Bus  namespace name, which is part of GEO DR pairing
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - alternate_name -- Alternate Name (Post failover) for Primary Namespace, when Namespace name and Alias name are same
    '''
    return _call_az("az servicebus georecovery-alias set", locals())


def show(alias, namespace_name, resource_group):
    '''
    shows properties of Service Bus Geo-Disaster Recovery Configuration Alias for Primay/Secondary Namespace

    Required Parameters:
    - alias -- Name of the Geo-Disaster Recovery Configuration Alias
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az servicebus georecovery-alias show", locals())


def list(namespace_name, resource_group):
    '''
    

    Required Parameters:
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az servicebus georecovery-alias list", locals())


def break_pair(alias, namespace_name, resource_group):
    '''
    Disables Service Bus Geo-Disaster Recovery Configuration Alias and stops replicating changes from primary to secondary namespaces

    Required Parameters:
    - alias -- Name of the Geo-Disaster Recovery Configuration Alias
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az servicebus georecovery-alias break-pair", locals())


def fail_over(alias, namespace_name, resource_group, parameters=None):
    '''
    Invokes Service Bus Geo-Disaster Recovery Configuration Alias failover and re-configure the alias to point to the secondary namespace

    Required Parameters:
    - alias -- Name of the Geo-Disaster Recovery Configuration Alias
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - parameters -- Parameters required to create an Alias(Disaster Recovery configuration).
    '''
    return _call_az("az servicebus georecovery-alias fail-over", locals())


def exists(alias, namespace_name, resource_group):
    '''
    Check if Geo Recovery Alias Name is available

    Required Parameters:
    - alias -- Name of Geo-Disaster Recovery Configuration Alias to check availability
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az servicebus georecovery-alias exists", locals())


def delete(alias, namespace_name, resource_group):
    '''
    Deletes Service Bus Geo-Disaster Recovery Configuration Alias request accepted

    Required Parameters:
    - alias -- Name of the Geo-Disaster Recovery Configuration Alias
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az servicebus georecovery-alias delete", locals())




'''
Manage autoscale settings.
'''
from ... pyaz_utils import _call_az
from . import profile, rule


def create(count, resource, action=None, disabled=None, email_administrator=None, email_coadministrators=None, location=None, max_count=None, min_count=None, name=None, resource_group=None, resource_namespace=None, resource_parent=None, resource_type=None, tags=None):
    '''
    Create new autoscale settings.

    Required Parameters:
    - count -- The numer of instances to use. If used with --min/max-count, the default number of instances to use.
    - resource -- Name or ID of the target resource.

    Optional Parameters:
    - action -- None
    - disabled -- Create the autoscale settings in a disabled state.
    - email_administrator -- Send email to subscription administrator on scaling.
    - email_coadministrators -- Send email to subscription co-administrators on scaling.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - max_count -- The maximum number of instances.
    - min_count -- The minimum number of instances.
    - name -- Name of the autoscale settings.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_namespace -- Target resource provider namespace.
    - resource_parent -- Target resource parent path, if applicable.
    - resource_type -- Target resource type. Can also accept namespace/type format (Ex: 'Microsoft.Compute/virtualMachines')
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az monitor autoscale create", locals())


def update(name, resource_group, add=None, add_action=None, count=None, email_administrator=None, email_coadministrators=None, enabled=None, force_string=None, max_count=None, min_count=None, remove=None, remove_action=None, set=None, tags=None):
    '''
    Update autoscale settings.

    Required Parameters:
    - name -- Name of the autoscale settings.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - add_action -- None
    - count -- The numer of instances to use. If used with --min/max-count, the default number of instances to use.
    - email_administrator -- Send email to subscription administrator on scaling.
    - email_coadministrators -- Send email to subscription co-administrators on scaling.
    - enabled -- Autoscale settings enabled status.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - max_count -- The maximum number of instances.
    - min_count -- The minimum number of instances.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - remove_action -- None
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az monitor autoscale update", locals())


def delete(name, resource_group):
    '''
    

    Required Parameters:
    - name -- Name of the autoscale settings.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az monitor autoscale delete", locals())


def show(name, resource_group):
    '''
    Show autoscale setting details.

    Required Parameters:
    - name -- Name of the autoscale settings.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az monitor autoscale show", locals())


def list(resource_group):
    '''
    

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az monitor autoscale list", locals())




'''
Manage log analytics workspace for a vm.
'''
from .... pyaz_utils import _call_az

def show(analytics_query, name, resource_group, timespan=None):
    '''
    Execute a query against the Log Analytics workspace linked with a VM.

    Required Parameters:
    - analytics_query -- Query to execute over Log Analytics data.
    - name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - timespan -- Timespan over which to query. Defaults to querying all available data.
    '''
    return _call_az("az vm monitor log show", locals())




from ... pyaz_utils import _call_az

def show(endpoint_name, name, profile_name, resource_group):
    '''
    Show details for the custom domain of a CDN.

    Required Parameters:
    - endpoint_name -- Name of the endpoint under the profile which is unique globally.
    - name -- Resource name of the custom domain.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cdn custom-domain show", locals())


def delete(endpoint_name, name, profile_name, resource_group):
    '''
    Delete the custom domain of a CDN.

    Required Parameters:
    - endpoint_name -- Name of the endpoint under the profile which is unique globally.
    - name -- Resource name of the custom domain.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cdn custom-domain delete", locals())


def list(endpoint_name, profile_name, resource_group):
    '''
    

    Required Parameters:
    - endpoint_name -- Name of the endpoint under the profile which is unique globally.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cdn custom-domain list", locals())


def create(endpoint_name, hostname, name, profile_name, resource_group, location=None, tags=None):
    '''
    Create a new custom domain to provide a hostname for a CDN endpoint.

    Required Parameters:
    - endpoint_name -- None
    - hostname -- None
    - name -- Resource name of the custom domain.
    - profile_name -- None
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az cdn custom-domain create", locals())


def enable_https(endpoint_name, name, profile_name, resource_group, min_tls_version=None, user_cert_group_name=None, user_cert_protocol_type=None, user_cert_secret_name=None, user_cert_secret_version=None, user_cert_subscription_id=None, user_cert_vault_name=None):
    '''
    Enable HTTPS for a custom domain. The resource name of the custom domain could be obtained using "az cdn custom-domain list".

    Required Parameters:
    - endpoint_name -- Name of the parent endpoint.
    - name -- Resource name of the custom domain.
    - profile_name -- Name of the parent profile.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - min_tls_version -- The minimum TLS version required for the custom domain.
    - user_cert_group_name -- The resource group of the KeyVault certificate
    - user_cert_protocol_type -- The protocol type of the certificate.
    - user_cert_secret_name -- The secret name of the KeyVault certificate
    - user_cert_secret_version -- The secret version of the KeyVault certificate, If not specified, the "Latest" version will always been used and the deployed certificate will be automatically rotated to the latest version when a newer version of the certificate is available.
    - user_cert_subscription_id -- The subscription id of the KeyVault certificate
    - user_cert_vault_name -- The vault name of the KeyVault certificate
    '''
    return _call_az("az cdn custom-domain enable-https", locals())


def disable_https(endpoint_name, name, profile_name, resource_group):
    '''
    

    Required Parameters:
    - endpoint_name -- Name of the endpoint under the profile which is unique globally.
    - name -- Resource name of the custom domain.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cdn custom-domain disable-https", locals())




from .... pyaz_utils import _call_az

def list(gateway_name, resource_group):
    '''
    List probes.

    Required Parameters:
    - gateway_name -- The name of the application gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway probe list", locals())


def show(gateway_name, name, resource_group):
    '''
    Get the details of a probe.

    Required Parameters:
    - gateway_name -- The name of the application gateway.
    - name -- The name of the probe.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway probe show", locals())


def delete(gateway_name, name, resource_group, no_wait=None):
    '''
    Delete a probe.

    Required Parameters:
    - gateway_name -- The name of the application gateway.
    - name -- The name of the probe.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az network application-gateway probe delete", locals())


def create(gateway_name, name, path, protocol, resource_group, host=None, host_name_from_http_settings=None, interval=None, match_body=None, match_status_codes=None, min_servers=None, no_wait=None, port=None, threshold=None, timeout=None):
    '''
    Create a probe.

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - name -- The name of the probe.
    - path -- The relative path of the probe. Valid paths start from "/"
    - protocol -- The HTTP settings protocol.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - host -- The name of the host to send the probe.
    - host_name_from_http_settings -- Use host header from HTTP settings.
    - interval -- The time interval in seconds between consecutive probes.
    - match_body -- Body that must be contained in the health response.
    - match_status_codes -- Space-separated list of allowed ranges of healthy status codes for the health response.
    - min_servers -- Minimum number of servers that are always marked healthy.
    - no_wait -- Do not wait for the long-running operation to finish.
    - port -- Custom port which will be used for probing the backend servers. The valid value ranges from 1 to 65535. In case not set, port from http settings will be used. This property is valid for Standard_v2 and WAF_v2 only.
    - threshold -- The number of failed probes after which the back end server is marked down.
    - timeout -- The probe timeout in seconds.
    '''
    return _call_az("az network application-gateway probe create", locals())


def update(gateway_name, name, resource_group, add=None, force_string=None, host=None, host_name_from_http_settings=None, interval=None, match_body=None, match_status_codes=None, min_servers=None, no_wait=None, path=None, port=None, protocol=None, remove=None, set=None, threshold=None, timeout=None):
    '''
    Update a probe.

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - name -- The name of the probe.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - host -- The name of the host to send the probe.
    - host_name_from_http_settings -- Use host header from HTTP settings.
    - interval -- The time interval in seconds between consecutive probes.
    - match_body -- Body that must be contained in the health response.
    - match_status_codes -- Space-separated list of allowed ranges of healthy status codes for the health response.
    - min_servers -- Minimum number of servers that are always marked healthy.
    - no_wait -- Do not wait for the long-running operation to finish.
    - path -- The relative path of the probe. Valid paths start from "/"
    - port -- Custom port which will be used for probing the backend servers. The valid value ranges from 1 to 65535. In case not set, port from http settings will be used. This property is valid for Standard_v2 and WAF_v2 only.
    - protocol -- The HTTP settings protocol.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - threshold -- The number of failed probes after which the back end server is marked down.
    - timeout -- The probe timeout in seconds.
    '''
    return _call_az("az network application-gateway probe update", locals())




from .... pyaz_utils import _call_az

def add(cluster_name, extension_name, extension_type, publisher, resource_group, type_handler_version, auto_upgrade_minor_version=None, force_update_tag=None, protected_setting=None, provision_after_extension=None, setting=None):
    '''
    Add an extension to the node type.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - extension_name -- extension name.
    - extension_type -- Specifies the type of the extension; an example is "CustomScriptExtension".
    - publisher -- The name of the extension handler publisher.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    - type_handler_version -- Specifies the version of the script handler.

    Optional Parameters:
    - auto_upgrade_minor_version -- Indicates whether the extension should use a newer minor version if one is available at deployment time. Once deployed, however, the extension will not upgrade minor versions unless redeployed, even with this property set to true.
    - force_update_tag -- If a value is provided and is different from the previous value, the extension handler will be forced to update even if the extension configuration has not changed.
    - protected_setting -- The extension can contain either protectedSettings or protectedSettingsFromKeyVault or no protected settings at all.
    - provision_after_extension -- Collection of extension names after which this extension needs to be provisioned.
    - setting -- Json formatted public settings for the extension.
    '''
    return _call_az("az sf managed-node-type vm-extension add", locals())


def delete(cluster_name, extension_name, resource_group):
    '''
    Delete an extension to the node type.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - extension_name -- extension name.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sf managed-node-type vm-extension delete", locals())




'''
Manage reservation entities
'''
from ... pyaz_utils import _call_az

def list(reservation_order_id):
    '''
    Get all reservations.

    Required Parameters:
    - reservation_order_id -- Order Id of the reservation
    '''
    return _call_az("az reservations reservation list", locals())


def show(reservation_id, reservation_order_id, expand=None):
    '''
    Get details of a reservation.

    Required Parameters:
    - reservation_id -- Id of the Reservation Item
    - reservation_order_id -- Order Id of the reservation

    Optional Parameters:
    - expand -- Supported value of this query is renewProperties
    '''
    return _call_az("az reservations reservation show", locals())


def list_history(reservation_id, reservation_order_id):
    '''
    Get history of a reservation.

    Required Parameters:
    - reservation_id -- Id of the Reservation Item
    - reservation_order_id -- Order Id of the reservation
    '''
    return _call_az("az reservations reservation list-history", locals())


def update(applied_scope_type, reservation_id, reservation_order_id, applied_scopes=None, instance_flexibility=None):
    '''
    Updates the applied scopes of the reservation.

    Required Parameters:
    - applied_scope_type -- None
    - reservation_id -- None
    - reservation_order_id -- None

    Optional Parameters:
    - applied_scopes -- None
    - instance_flexibility -- None
    '''
    return _call_az("az reservations reservation update", locals())


def split(quantity_1, quantity_2, reservation_id, reservation_order_id):
    '''
    Split a reservation.

    Required Parameters:
    - quantity_1 -- None
    - quantity_2 -- None
    - reservation_id -- None
    - reservation_order_id -- None
    '''
    return _call_az("az reservations reservation split", locals())


def merge(reservation_id_1, reservation_id_2, reservation_order_id):
    '''
    Merge two reservations.

    Required Parameters:
    - reservation_id_1 -- None
    - reservation_id_2 -- None
    - reservation_order_id -- None
    '''
    return _call_az("az reservations reservation merge", locals())




from ... pyaz_utils import _call_az

def create(name, advanced_filter=None, azure_active_directory_application_id_or_uri=None, azure_active_directory_tenant_id=None, deadletter_endpoint=None, deadletter_identity=None, deadletter_identity_endpoint=None, delivery_attribute_mapping=None, delivery_identity=None, delivery_identity_endpoint=None, delivery_identity_endpoint_type=None, enable_advanced_filtering_on_arrays=None, endpoint=None, endpoint_type=None, event_delivery_schema=None, event_ttl=None, expiration_date=None, included_event_types=None, labels=None, max_delivery_attempts=None, max_events_per_batch=None, preferred_batch_size_in_kilobytes=None, source_resource_id=None, storage_queue_msg_ttl=None, subject_begins_with=None, subject_case_sensitive=None, subject_ends_with=None):
    '''
    Create a new event subscription.

    Required Parameters:
    - name -- Name of the event subscription.

    Optional Parameters:
    - advanced_filter -- None
    - azure_active_directory_application_id_or_uri -- The Azure Active Directory Application Id or Uri to get the access token that will be included as the bearer token in delivery requests. Applicable only for webhook as a destination
    - azure_active_directory_tenant_id -- The Azure Active Directory Tenant Id to get the access token that will be included as the bearer token in delivery requests. Applicable only for webhook as a destination
    - deadletter_endpoint -- The Azure resource ID of an Azure Storage blob container destination where EventGrid should deadletter undeliverable events for this event subscription.
    - deadletter_identity -- The identity type of the deadletter destination resource.
    - deadletter_identity_endpoint -- The Azure resource ID of an Azure Storage blob container destination with identity where EventGrid should deadletter undeliverable events for this event subscription.
    - delivery_attribute_mapping -- Add delivery attribute mapping to send additional information via HTTP headers when delivering events. This attribute is valid for all destination types except StorageQueue. Multiple attributes can be specified by using more than one `--delivery-attribute-mapping` argument
    - delivery_identity -- The identity type of the delivery destination resource (e.g., storage queue, or eventhub).
    - delivery_identity_endpoint -- Endpoint with identity where EventGrid should deliver events matching this event subscription. For webhook endpoint type, this should be the corresponding webhook URL. For other endpoint types, this should be the Azure resource identifier of the endpoint.
    - delivery_identity_endpoint_type -- None
    - enable_advanced_filtering_on_arrays -- Allows advanced filters to be evaluated against an array of values instead of expecting a singular value.
    - endpoint -- Endpoint where EventGrid should deliver events matching this event subscription. For webhook endpoint type, this should be the corresponding webhook URL. For other endpoint types, this should be the Azure resource identifier of the endpoint. It is expected that the destination endpoint to be already created and available for use before executing any Event Grid command.
    - endpoint_type -- None
    - event_delivery_schema -- The schema in which events should be delivered for this event subscription. By default, events will be delivered in the same schema in which they are published (based on the corresponding topic's input schema).
    - event_ttl -- Event time to live (in minutes). Must be a number between 1 and 1440.
    - expiration_date -- Date or datetime (in UTC, e.g. '2018-11-30T11:59:59+00:00' or '2018-11-30') after which the event subscription would expire. By default, there is no expiration for the event subscription.
    - included_event_types -- A space-separated list of event types (e.g., Microsoft.Storage.BlobCreated and Microsoft.Storage.BlobDeleted). In order to subscribe to all default event types, do not specify any value for this argument. For event grid topics, event types are customer defined. For Azure events, e.g., Storage Accounts, IoT Hub, etc., you can query their event types using this CLI command 'az eventgrid topic-type list-event-types'.
    - labels -- A space-separated list of labels to associate with this event subscription.
    - max_delivery_attempts -- Maximum number of delivery attempts. Must be a number between 1 and 30.
    - max_events_per_batch -- Maximum number of events in a batch. Must be a number between 1 and 5000.
    - preferred_batch_size_in_kilobytes -- Preferred batch size in kilobytes. Must be a number between 1 and 1024.
    - source_resource_id -- Fully qualified identifier of the source Azure resource.
    - storage_queue_msg_ttl -- Storage queue message time to live in seconds.
    - subject_begins_with -- An optional string to filter events for an event subscription based on a prefix. Wildcard characters are not supported.
    - subject_case_sensitive -- Specify to indicate whether the subject fields should be compared in a case sensitive manner. True if flag present.
    - subject_ends_with -- An optional string to filter events for an event subscription based on a suffix. Wildcard characters are not supported.
    '''
    return _call_az("az eventgrid event-subscription create", locals())


def show(name, include_full_endpoint_url=None, include_static_delivery_attribute_secret=None, source_resource_id=None):
    '''
    Get the details of an event subscription.

    Required Parameters:
    - name -- Name of the event subscription.

    Optional Parameters:
    - include_full_endpoint_url -- Specify to indicate whether the full endpoint URL should be returned. True if flag present.
    - include_static_delivery_attribute_secret -- Indicate whether any static delivery attribute secrets should be returned. True if flag present.
    - source_resource_id -- Fully qualified identifier of the source Azure resource.
    '''
    return _call_az("az eventgrid event-subscription show", locals())


def delete(name, source_resource_id=None):
    '''
    Delete an event subscription.

    Required Parameters:
    - name -- Name of the event subscription.

    Optional Parameters:
    - source_resource_id -- Fully qualified identifier of the source Azure resource.
    '''
    return _call_az("az eventgrid event-subscription delete", locals())


def list(location=None, odata_query=None, resource_group=None, source_resource_id=None, topic_type_name=None):
    '''
    List event subscriptions.

    Optional Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - odata_query -- The OData query used for filtering the list results. Filtering is currently allowed on the Name property only. The supported operations include: CONTAINS, eq (for equal), ne (for not equal), AND, OR and NOT.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - source_resource_id -- Fully qualified identifier of the source Azure resource.
    - topic_type_name -- Name of the topic type.
    '''
    return _call_az("az eventgrid event-subscription list", locals())


def update(name, add=None, advanced_filter=None, deadletter_endpoint=None, deadletter_identity=None, deadletter_identity_endpoint=None, delivery_attribute_mapping=None, delivery_identity=None, delivery_identity_endpoint=None, delivery_identity_endpoint_type=None, enable_advanced_filtering_on_arrays=None, endpoint=None, endpoint_type=None, force_string=None, included_event_types=None, labels=None, remove=None, set=None, source_resource_id=None, storage_queue_msg_ttl=None, subject_begins_with=None, subject_ends_with=None):
    '''
    Update an event subscription.

    Required Parameters:
    - name -- Name of the event subscription.

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - advanced_filter -- None
    - deadletter_endpoint -- The Azure resource ID of an Azure Storage blob container destination where EventGrid should deadletter undeliverable events for this event subscription.
    - deadletter_identity -- The identity type of the deadletter destination resource.
    - deadletter_identity_endpoint -- The Azure resource ID of an Azure Storage blob container destination with identity where EventGrid should deadletter undeliverable events for this event subscription.
    - delivery_attribute_mapping -- Add delivery attribute mapping to send additional information via HTTP headers when delivering events. This attribute is valid for all destination types except StorageQueue. Multiple attributes can be specified by using more than one `--delivery-attribute-mapping` argument
    - delivery_identity -- The identity type of the delivery destination resource (e.g., storage queue, or eventhub).
    - delivery_identity_endpoint -- Endpoint with identity where EventGrid should deliver events matching this event subscription. For webhook endpoint type, this should be the corresponding webhook URL. For other endpoint types, this should be the Azure resource identifier of the endpoint.
    - delivery_identity_endpoint_type -- None
    - enable_advanced_filtering_on_arrays -- Allows advanced filters to be evaluated against an array of values instead of expecting a singular value.
    - endpoint -- Endpoint where EventGrid should deliver events matching this event subscription. For webhook endpoint type, this should be the corresponding webhook URL. For other endpoint types, this should be the Azure resource identifier of the endpoint. It is expected that the destination endpoint to be already created and available for use before executing any Event Grid command.
    - endpoint_type -- None
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - included_event_types -- A space-separated list of event types (e.g., Microsoft.Storage.BlobCreated and Microsoft.Storage.BlobDeleted). In order to subscribe to all default event types, do not specify any value for this argument. For event grid topics, event types are customer defined. For Azure events, e.g., Storage Accounts, IoT Hub, etc., you can query their event types using this CLI command 'az eventgrid topic-type list-event-types'.
    - labels -- A space-separated list of labels to associate with this event subscription.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - source_resource_id -- Fully qualified identifier of the source Azure resource.
    - storage_queue_msg_ttl -- Storage queue message time to live in seconds.
    - subject_begins_with -- An optional string to filter events for an event subscription based on a prefix. Wildcard characters are not supported.
    - subject_ends_with -- An optional string to filter events for an event subscription based on a suffix. Wildcard characters are not supported.
    '''
    return _call_az("az eventgrid event-subscription update", locals())




from .... pyaz_utils import _call_az

def create(auto_renew, commitment_plan_name, hosting_model, name, plan_type, resource_group, current_count=None, current_tier=None, next_count=None, next_tier=None):
    '''
    Create a commitment plan for Azure Cognitive Services account.

    Required Parameters:
    - auto_renew -- A boolean indicating whether to apply auto renew.
    - commitment_plan_name -- Cognitive Services account commitment plan name
    - hosting_model -- Cognitive Services account hosting model
    - name -- cognitive service account name
    - plan_type -- Cognitive Services account commitment plan type
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - current_count -- Cognitive Services account commitment plan current commitment period count.
    - current_tier -- Cognitive Services account commitment plan current commitment period tier.
    - next_count -- Cognitive Services account commitment plan next commitment period count.
    - next_tier -- Cognitive Services account commitment plan next commitment period tier.
    '''
    return _call_az("az cognitiveservices account commitment-plan create", locals())


def delete(commitment_plan_name, name, resource_group):
    '''
    Delete a commitment plan from Azure Cognitive Services account.

    Required Parameters:
    - commitment_plan_name -- Cognitive Services account commitment plan name
    - name -- cognitive service account name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cognitiveservices account commitment-plan delete", locals())


def show(commitment_plan_name, name, resource_group):
    '''
    Show a commitment plan from Azure Cognitive Services account.

    Required Parameters:
    - commitment_plan_name -- Cognitive Services account commitment plan name
    - name -- cognitive service account name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cognitiveservices account commitment-plan show", locals())


def list(name, resource_group):
    '''
    Show all commitment plans from Azure Cognitive Services account.

    Required Parameters:
    - name -- cognitive service account name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cognitiveservices account commitment-plan list", locals())




from ... pyaz_utils import _call_az

def show(name, protectable_item_type, resource_group, server_name, vault_name, workload_type):
    '''
    Retrieve the specified protectable item within the given container.

    Required Parameters:
    - name -- Name of the protectable item.
    - protectable_item_type -- Specify the type of applications within the Resource which should be discovered and protected by Azure Backup. 
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server_name -- Parent Server name of the item.
    - vault_name -- Name of the Recovery services vault.
    - workload_type -- Specify the type of applications within the Resource which should be discovered and protected by Azure Backup. 
    '''
    return _call_az("az backup protectable-item show", locals())


def list(resource_group, vault_name, workload_type, backup_management_type=None, container_name=None, protectable_item_type=None, server_name=None):
    '''
    Retrieve all protectable items within a certain container or across all registered containers.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vault_name -- Name of the Recovery services vault.
    - workload_type -- Specify the type of applications within the Resource which should be discovered and protected by Azure Backup. 

    Optional Parameters:
    - backup_management_type -- Specify the backup management type. Define how Azure Backup manages the backup of entities within the ARM resource. For eg: AzureWorkloads refers to workloads installed within Azure VMs, AzureStorage refers to entities within Storage account. Required only if friendly name is used as Container name.
    - container_name -- Name of the backup container. Accepts 'Name' or 'FriendlyName' from the output of az backup container list command. If 'FriendlyName' is passed then BackupManagementType is required.
    - protectable_item_type -- Specify the type of applications within the Resource which should be discovered and protected by Azure Backup. 
    - server_name -- Parent Server name of the item.
    '''
    return _call_az("az backup protectable-item list", locals())


def initialize(container_name, resource_group, vault_name, workload_type):
    '''
    Trigger the discovery of any unprotected items of the given workload type in the given container.

    Required Parameters:
    - container_name -- Name of the backup container. Accepts 'Name' or 'FriendlyName' from the output of az backup container list command. If 'FriendlyName' is passed then BackupManagementType is required.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vault_name -- Name of the Recovery services vault.
    - workload_type -- Specify the type of applications within the Resource which should be discovered and protected by Azure Backup. 
    '''
    return _call_az("az backup protectable-item initialize", locals())




'''
Manage dedicated Redis caches for your Azure applications.
'''
from .. pyaz_utils import _call_az
from . import firewall_rules, patch_schedule, server_link


def create(location, name, resource_group, sku, vm_size, enable_non_ssl_port=None, minimum_tls_version=None, redis_configuration=None, redis_version=None, replicas_per_master=None, shard_count=None, static_ip=None, subnet_id=None, tags=None, tenant_settings=None, zones=None):
    '''
    Create new Redis Cache instance.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- Name of the Redis cache.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - sku -- Type of Redis cache.
    - vm_size -- Size of Redis cache to deploy. Basic and Standard Cache sizes start with C. Premium Cache sizes start with P

    Optional Parameters:
    - enable_non_ssl_port -- If specified, then the non-ssl redis server port (6379) will be enabled.
    - minimum_tls_version -- Specifies the TLS version required by clients to connect to cache
    - redis_configuration -- JSON encoded configuration settings. Use @{file} to load from a file.
    - redis_version -- Redis version. Only major version will be used in create/update request with current valid values: (4, 6)
    - replicas_per_master -- The number of replicas to be created per master.
    - shard_count -- The number of shards to be created on a Premium Cluster Cache.
    - static_ip -- Specify a static ip if required for the VNET. If you do not specify a static IP then an IP address is chosen automatically
    - subnet_id -- The full resource ID of a subnet in a virtual network to deploy the redis cache in. Example format /subscriptions/{subid}/resourceGroups/{resourceGroupName}/providers/Microsoft.{Network|ClassicNetwork}/virtualNetworks/vnet1/subnets/subnet1
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - tenant_settings -- Space-separated tenant settings in key[=value] format
    - zones -- Space-separated list of availability zones into which to provision the resource.
    '''
    return _call_az("az redis create", locals())


def delete(name, resource_group, yes=None):
    '''
    

    Required Parameters:
    - name -- Name of the Redis cache.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az redis delete", locals())


def export(container, name, prefix, resource_group, file_format=None):
    '''
    Export data stored in a Redis cache.

    Required Parameters:
    - container -- SAS url for container where data needs to be exported to
    - name -- Name of the Redis cache.
    - prefix -- Prefix to use for exported files
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - file_format -- Format of the blob (Currently rdb is the only supported format, with other formats expected in the future)
    '''
    return _call_az("az redis export", locals())


def force_reboot(name, reboot_type, resource_group, shard_id=None):
    '''
    Reboot specified Redis node(s).

    Required Parameters:
    - name -- Name of the Redis cache.
    - reboot_type -- Which Redis node(s) to reboot. Depending on this value data loss is possible.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - shard_id -- If clustering is enabled, the ID of the shard to be rebooted.
    '''
    return _call_az("az redis force-reboot", locals())


def import_method(files, name, resource_group, file_format=None):
    '''
    Import data into Redis cache.

    Required Parameters:
    - files -- SAS url for blobs that needs to be imported
    - name -- Name of the Redis cache.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - file_format -- Format of the blob (Currently rdb is the only supported format, with other formats expected in the future)
    '''
    return _call_az("az redis import-method", locals())


def import_(files, name, resource_group, file_format=None):
    '''
    Import data into a Redis cache.

    Required Parameters:
    - files -- SAS url for blobs that needs to be imported
    - name -- Name of the Redis cache.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - file_format -- Format of the blob (Currently rdb is the only supported format, with other formats expected in the future)
    '''
    return _call_az("az redis import", locals())


def list(resource_group=None):
    '''
    List Redis Caches.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az redis list", locals())


def list_keys(name, resource_group):
    '''
    

    Required Parameters:
    - name -- Name of the Redis cache.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az redis list-keys", locals())


def regenerate_keys(key_type, name, resource_group):
    '''
    Regenerate Redis cache's access keys.

    Required Parameters:
    - key_type -- The Redis access key to regenerate.
    - name -- Name of the Redis cache.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az redis regenerate-keys", locals())


def show(name, resource_group):
    '''
    

    Required Parameters:
    - name -- Name of the Redis cache.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az redis show", locals())


def update(name, resource_group, add=None, force_string=None, remove=None, set=None, sku=None, vm_size=None):
    '''
    Update a Redis cache.

    Required Parameters:
    - name -- Name of the Redis cache.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - sku -- Type of Redis cache.
    - vm_size -- Size of Redis cache to deploy. Basic and Standard Cache sizes start with C. Premium Cache sizes start with P
    '''
    return _call_az("az redis update", locals())




'''
Manage Azure Data Migration Service (DMS) instances.
'''
from .. pyaz_utils import _call_az
from . import project


def check_name(location, name):
    '''
    Check if a given DMS instance name is available in a given region as well as the name's validity.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- The name of the Service.
    '''
    return _call_az("az dms check-name", locals())


def check_status(name, resource_group):
    '''
    Perform a health check and return the status of the service and virtual machine size.

    Required Parameters:
    - name -- The name of the Service.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az dms check-status", locals())


def create(location, name, resource_group, sku_name, subnet, no_wait=None, tags=None):
    '''
    Create an instance of the Data Migration Service.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- The name of the Service.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - sku_name -- None
    - subnet -- None

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - tags -- A space-delimited list of tags in "tag1[=value1]" format.
    '''
    return _call_az("az dms create", locals())


def delete(name, resource_group, delete_running_tasks=None, no_wait=None, yes=None):
    '''
    Delete an instance of the Data Migration Service.

    Required Parameters:
    - name -- The name of the Service.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - delete_running_tasks -- None
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az dms delete", locals())


def list(resource_group=None):
    '''
    List the DMS instances within your currently configured subscription (to set this use "az account set"). If provided, only show the instances within a given resource group.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az dms list", locals())


def show(name, resource_group):
    '''
    Show the details for an instance of the Data Migration Service.

    Required Parameters:
    - name -- The name of the Service.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az dms show", locals())


def start(name, resource_group, no_wait=None):
    '''
    Start an instance of the Data Migration Service. It can then be used to run data migrations.

    Required Parameters:
    - name -- The name of the Service.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az dms start", locals())


def stop(name, resource_group, no_wait=None):
    '''
    Stop an instance of the Data Migration Service. While stopped, it can't be used to run data migrations and the owner won't be billed.

    Required Parameters:
    - name -- The name of the Service.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az dms stop", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the DMS instance is met.

    Required Parameters:
    - name -- The name of the Service.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az dms wait", locals())


def list_skus():
    '''
    List the SKUs that are supported by the Data Migration Service.
    '''
    return _call_az("az dms list-skus", locals())




from ... pyaz_utils import _call_az
from . import version


def list(cluster_name, resource_group):
    '''
    List managed application types of a given managed cluster.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sf managed-application-type list", locals())


def delete(cluster_name, name, resource_group):
    '''
    Delete a managed application type.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - name -- Specify the application type name.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sf managed-application-type delete", locals())


def show(cluster_name, name, resource_group):
    '''
    Show the properties of a managed application type on an Azure Service Fabric managed cluster.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - name -- Specify the application type name.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sf managed-application-type show", locals())


def create(cluster_name, name, resource_group, tags=None):
    '''
    Create a new managed application type on an Azure Service Fabric managed cluster.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - name -- Specify the application type name.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az sf managed-application-type create", locals())


def update(cluster_name, name, resource_group, tags=None):
    '''
    Update an managed application type.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - name -- Specify the application type name.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az sf managed-application-type update", locals())




'''
Manage operations on a managed instance.
'''
from .... pyaz_utils import _call_az

def list(managed_instance, resource_group):
    '''
    

    Required Parameters:
    - managed_instance -- Name of the Azure SQL Managed Instance.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sql mi op list", locals())


def show(managed_instance, name, resource_group):
    '''
    

    Required Parameters:
    - managed_instance -- Name of the Azure SQL Managed Instance.
    - name -- The unique name of the operation to show.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sql mi op show", locals())


def cancel(managed_instance, name, resource_group):
    '''
    

    Required Parameters:
    - managed_instance -- Name of the Azure SQL Managed Instance.
    - name -- The unique name of the operation to cancel.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sql mi op cancel", locals())




from .... pyaz_utils import _call_az

def reimage(cluster_name, node_name, resource_group, force=None):
    '''
    Reimage nodes of a node type.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - node_name -- list of target nodes to perform the operation.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - force -- Using this flag will force the operation even if service fabric is unable to disable the nodes. Use with caution as this might cause data loss if stateful workloads are running on the node.
    '''
    return _call_az("az sf managed-node-type node reimage", locals())


def restart(cluster_name, node_name, resource_group, force=None):
    '''
    Restart nodes of a node type.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - node_name -- list of target nodes to perform the operation.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - force -- Using this flag will force the operation even if service fabric is unable to disable the nodes. Use with caution as this might cause data loss if stateful workloads are running on the node.
    '''
    return _call_az("az sf managed-node-type node restart", locals())


def delete(cluster_name, node_name, resource_group, force=None):
    '''
    Delete nodes of a node type.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - node_name -- list of target nodes to perform the operation.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - force -- Using this flag will force the operation even if service fabric is unable to disable the nodes. Use with caution as this might cause data loss if stateful workloads are running on the node.
    '''
    return _call_az("az sf managed-node-type node delete", locals())




from ... pyaz_utils import _call_az
from . import op


def create(name, resource_group, server, capacity=None, db_dtu_max=None, db_dtu_min=None, family=None, license_type=None, maint_config_id=None, max_size=None, no_wait=None, tags=None, tier=None, zone_redundant=None):
    '''
    Create an elastic pool.

    Required Parameters:
    - name -- The name of the elastic pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`

    Optional Parameters:
    - capacity -- The capacity component of the sku in integer number of DTUs or vcores.
    - db_dtu_max -- The maximum capacity (in DTUs or vcores) any one database can consume.
    - db_dtu_min -- The minumum capacity (in DTUs or vcores) each database is guaranteed.
    - family -- The compute generation component of the sku (for vcore skus only). Allowed values include: Gen4, Gen5.
    - license_type -- The license type to apply for this elastic pool. Possible values include: "LicenseIncluded", "BasePrice".
    - maint_config_id -- Specified maintenance configuration id or name for this resource.
    - max_size -- The max storage size. If no unit is specified, defaults to bytes (B).
    - no_wait -- Do not wait for the long-running operation to finish.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - tier -- The edition component of the sku. Allowed values include: Basic, Standard, Premium, GeneralPurpose, BusinessCritical.
    - zone_redundant -- Specifies whether to enable zone redundancy
    '''
    return _call_az("az sql elastic-pool create", locals())


def delete(name, resource_group, server, no_wait=None):
    '''
    

    Required Parameters:
    - name -- The name of the elastic pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az sql elastic-pool delete", locals())


def show(name, resource_group, server):
    '''
    

    Required Parameters:
    - name -- The name of the elastic pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql elastic-pool show", locals())


def list(resource_group, server, skip=None):
    '''
    

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`

    Optional Parameters:
    - skip -- The number of elements in the collection to skip.
    '''
    return _call_az("az sql elastic-pool list", locals())


def update(name, resource_group, server, add=None, capacity=None, db_dtu_max=None, db_dtu_min=None, family=None, force_string=None, maint_config_id=None, max_size=None, no_wait=None, remove=None, set=None, tier=None, zone_redundant=None):
    '''
    Update an elastic pool.

    Required Parameters:
    - name -- The name of the elastic pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - capacity -- The capacity component of the sku in integer number of DTUs or vcores.
    - db_dtu_max -- The maximum capacity (in DTUs or vcores) any one database can consume.
    - db_dtu_min -- The minumum capacity (in DTUs or vcores) each database is guaranteed.
    - family -- The compute generation component of the sku (for vcore skus only). Allowed values include: Gen4, Gen5.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - maint_config_id -- Specified maintenance configuration id or name for this resource.
    - max_size -- The max storage size. If no unit is specified, defaults to bytes (B).
    - no_wait -- Do not wait for the long-running operation to finish.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - tier -- The edition component of the sku. Allowed values include: Basic, Standard, Premium, GeneralPurpose, BusinessCritical.
    - zone_redundant -- Specifies whether to enable zone redundancy
    '''
    return _call_az("az sql elastic-pool update", locals())


def list_dbs(name, resource_group, server):
    '''
    

    Required Parameters:
    - name -- The name of the elastic pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql elastic-pool list-dbs", locals())


def list_editions(location, available=None, dtu=None, show_details=None, tier=None, vcores=None):
    '''
    List elastic pool editions available for the active subscription.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.

    Optional Parameters:
    - available -- If specified, show only results that are available in the specified region.
    - dtu -- Number of DTUs to search for. If unspecified, all DTU sizes are shown.
    - show_details -- List of additional details to include in output.
    - tier -- Edition to search for. If unspecified, all editions are shown.
    - vcores -- Number of vcores to search for. If unspecified, all vcore sizes are shown.
    '''
    return _call_az("az sql elastic-pool list-editions", locals())




from .... pyaz_utils import _call_az

def list(database_rid, instance_id, location):
    '''
    List all the versions of all the mongodb collections that were created / modified / deleted in the given database and restorable account.

    Required Parameters:
    - database_rid -- Rid of the database
    - instance_id -- InstanceId of the Account
    - location -- Location
    '''
    return _call_az("az cosmosdb mongodb restorable-collection list", locals())




'''
Manage environment of the static app.
'''
from ... pyaz_utils import _call_az

def list(name, resource_group=None):
    '''
    List all environment of the static app including production.

    Required Parameters:
    - name -- Name of the static site

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az staticwebapp environment list", locals())


def show(name, environment_name=None, resource_group=None):
    '''
    Show information about the production environment or the specified environment.

    Required Parameters:
    - name -- Name of the static site

    Optional Parameters:
    - environment_name -- Name of the environment of static site
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az staticwebapp environment show", locals())


def functions(name, environment_name=None, resource_group=None):
    '''
    Show information about functions.

    Required Parameters:
    - name -- Name of the static site

    Optional Parameters:
    - environment_name -- Name of the environment of static site
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az staticwebapp environment functions", locals())


def delete(name, environment_name=None, resource_group=None, yes=None):
    '''
    Delete the static app production environment or the specified environment.

    Required Parameters:
    - name -- Name of the static site

    Optional Parameters:
    - environment_name -- Name of the environment of static site
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az staticwebapp environment delete", locals())




'''
Allows management operations of triggered webjobs on a web app.
'''
from .... pyaz_utils import _call_az

def list(name, resource_group, slot=None):
    '''
    List all triggered webjobs hosted on a web app.

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az webapp webjob triggered list", locals())


def remove(name, resource_group, webjob_name, slot=None):
    '''
    Delete a specific triggered webjob hosted on a web app.

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - webjob_name -- The name of the webjob

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az webapp webjob triggered remove", locals())


def run(name, resource_group, webjob_name, slot=None):
    '''
    Run a specific triggered webjob hosted on a web app.

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - webjob_name -- The name of the webjob

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az webapp webjob triggered run", locals())


def log(name, resource_group, webjob_name, slot=None):
    '''
    Get history of a specific triggered webjob hosted on a web app.

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - webjob_name -- The name of the webjob

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az webapp webjob triggered log", locals())




'''
Manage resource policy remediation deployments.
'''
from .... pyaz_utils import _call_az

def list(name, management_group=None, namespace=None, parent=None, resource=None, resource_group=None, resource_type=None):
    '''
    Lists deployments for a resource policy remediation.

    Required Parameters:
    - name -- Name of the remediation.

    Optional Parameters:
    - management_group -- Name of management group.
    - namespace -- Provider namespace (Ex: Microsoft.Provider).
    - parent -- The parent path (Ex: resourceTypeA/nameA/resourceTypeB/nameB).
    - resource -- Resource ID or resource name. If a name is given, please provide the resource group and other relevant resource id arguments.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_type -- Resource type (Ex: resourceTypeC).
    '''
    return _call_az("az policy remediation deployment list", locals())




'''
Manage certificates.
'''
from ... pyaz_utils import _call_az
from . import contact, issuer, pending


def create(name, policy, vault_name, disabled=None, tags=None, validity=None):
    '''
    Create a Key Vault certificate.

    Required Parameters:
    - name -- Name of the certificate.
    - policy -- JSON encoded policy definition. Use @{file} to load from a file(e.g. @my_policy.json).
    - vault_name -- Name of the Vault.

    Optional Parameters:
    - disabled -- Create certificate in disabled state.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - validity -- Number of months the certificate is valid for. Overrides the value specified with --policy/-p
    '''
    return _call_az("az keyvault certificate create", locals())


def list(id=None, include_pending=None, maxresults=None, vault_name=None):
    '''
    

    Optional Parameters:
    - id -- Full URI of the Vault or HSM. If specified all other 'Id' arguments should be omitted.
    - include_pending -- Specifies whether to include certificates which are not completely provisioned.
    - maxresults -- Maximum number of results to return in a page. If not specified the service will return up to 25 results.
    - vault_name -- Name of the Key Vault. Required if --id is not specified.
    '''
    return _call_az("az keyvault certificate list", locals())


def list_versions(id=None, maxresults=None, name=None, vault_name=None):
    '''
    

    Optional Parameters:
    - id -- Id of the certificate. If specified all other 'Id' arguments should be omitted.
    - maxresults -- Maximum number of results to return in a page. If not specified the service will return up to 25 results.
    - name -- Name of the certificate. Required if --id is not specified.
    - vault_name -- Name of the Key Vault. Required if --id is not specified.
    '''
    return _call_az("az keyvault certificate list-versions", locals())


def list_deleted(vault_name, id=None, include_pending=None, maxresults=None):
    '''
    

    Required Parameters:
    - vault_name -- Name of the Vault.

    Optional Parameters:
    - id -- Full URI of the Vault. If specified all other 'Id' arguments should be omitted.
    - include_pending -- Specifies whether to include certificates which are not completely provisioned.
    - maxresults -- Maximum number of results to return in a page. If not specified the service will return up to 25 results.
    '''
    return _call_az("az keyvault certificate list-deleted", locals())


def show(id=None, name=None, vault_name=None, version=None):
    '''
    

    Optional Parameters:
    - id -- Id of the certificate. If specified all other 'Id' arguments should be omitted.
    - name -- Name of the certificate. Required if --id is not specified.
    - vault_name -- Name of the Key Vault. Required if --id is not specified.
    - version -- The certificate version. If omitted, uses the latest version.
    '''
    return _call_az("az keyvault certificate show", locals())


def show_deleted(id=None, name=None, vault_name=None):
    '''
    

    Optional Parameters:
    - id -- The recovery id of the certificate. If specified all other 'Id' arguments should be omitted.
    - name -- Name of the certificate. Required if --id is not specified.
    - vault_name -- Name of the Vault. Required if --id is not specified.
    '''
    return _call_az("az keyvault certificate show-deleted", locals())


def delete(id=None, name=None, vault_name=None):
    '''
    

    Optional Parameters:
    - id -- Id of the certificate. If specified all other 'Id' arguments should be omitted.
    - name -- Name of the certificate. Required if --id is not specified.
    - vault_name -- Name of the Key Vault. Required if --id is not specified.
    '''
    return _call_az("az keyvault certificate delete", locals())


def purge(id=None, name=None, vault_name=None):
    '''
    

    Optional Parameters:
    - id -- The recovery id of the certificate. If specified all other 'Id' arguments should be omitted.
    - name -- Name of the certificate. Required if --id is not specified.
    - vault_name -- Name of the Vault. Required if --id is not specified.
    '''
    return _call_az("az keyvault certificate purge", locals())


def recover(id=None, name=None, vault_name=None):
    '''
    

    Optional Parameters:
    - id -- The recovery id of the certificate. If specified all other 'Id' arguments should be omitted.
    - name -- Name of the certificate. Required if --id is not specified.
    - vault_name -- Name of the Vault. Required if --id is not specified.
    '''
    return _call_az("az keyvault certificate recover", locals())


def set_attributes(certificate_attributes=None, enabled=None, id=None, name=None, policy=None, tags=None, vault_name=None, version=None):
    '''
    

    Optional Parameters:
    - certificate_attributes -- ==SUPPRESS==
    - enabled -- Enable the certificate.
    - id -- Id of the certificate. If specified all other 'Id' arguments should be omitted.
    - name -- Name of the certificate. Required if --id is not specified.
    - policy -- JSON encoded policy definition. Use @{file} to load from a file(e.g. @my_policy.json).
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - vault_name -- Name of the Key Vault. Required if --id is not specified.
    - version -- The certificate version. If omitted, uses the latest version.
    '''
    return _call_az("az keyvault certificate set-attributes", locals())


def import_(file, name, vault_name, disabled=None, password=None, policy=None, tags=None):
    '''
    Import a certificate into KeyVault.

    Required Parameters:
    - file -- PKCS12 file or PEM file containing the certificate and private key.
    - name -- Name of the certificate.
    - vault_name -- Name of the Vault.

    Optional Parameters:
    - disabled -- Import the certificate in disabled state.
    - password -- If the private key in certificate is encrypted, the password used for encryption.
    - policy -- JSON encoded policy definition. Use @{file} to load from a file(e.g. @my_policy.json).
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az keyvault certificate import", locals())


def download(file, encoding=None, id=None, name=None, vault_name=None, version=None):
    '''
    Download the public portion of a Key Vault certificate.

    Required Parameters:
    - file -- File to receive the binary certificate contents.

    Optional Parameters:
    - encoding -- Encoding of the certificate. DER will create a binary DER formatted x509 certificate, and PEM will create a base64 PEM x509 certificate.
    - id -- Id of the certificate. If specified all other 'Id' arguments should be omitted.
    - name -- Name of the certificate. Required if --id is not specified.
    - vault_name -- Name of the Key Vault. Required if --id is not specified.
    - version -- The certificate version. If omitted, uses the latest version.
    '''
    return _call_az("az keyvault certificate download", locals())


def get_default_policy(scaffold=None):
    '''
    Get the default policy for self-signed certificates.

    Optional Parameters:
    - scaffold -- create a fully formed policy structure with default values
    '''
    return _call_az("az keyvault certificate get-default-policy", locals())


def backup(file, id=None, name=None, vault_name=None):
    '''
    

    Required Parameters:
    - file -- Local file path in which to store certificate backup.

    Optional Parameters:
    - id -- Id of the certificate. If specified all other 'Id' arguments should be omitted.
    - name -- Name of the certificate. Required if --id is not specified.
    - vault_name -- Name of the Key Vault. Required if --id is not specified.
    '''
    return _call_az("az keyvault certificate backup", locals())


def restore(file, vault_name):
    '''
    

    Required Parameters:
    - file -- Local certificate backup from which to restore certificate.
    - vault_name -- Name of the Vault.
    '''
    return _call_az("az keyvault certificate restore", locals())




'''
Manage template solutions provided and maintained by Independent Software Vendors (ISVs).
'''
from .. pyaz_utils import _call_az
from . import definition


def create(kind, managed_rg_id, name, resource_group, location=None, managedapp_definition_id=None, parameters=None, plan_name=None, plan_product=None, plan_publisher=None, plan_version=None, tags=None):
    '''
    Create a managed application.

    Required Parameters:
    - kind -- the managed application kind. can be marketplace or servicecatalog
    - managed_rg_id -- the resource group managed by the managed application
    - name -- the managed application name
    - resource_group -- the resource group of the managed application

    Optional Parameters:
    - location -- the managed application location
    - managedapp_definition_id -- the full qualified managed application definition id
    - parameters -- JSON formatted string or a path to a file with such content
    - plan_name -- the managed application package plan name
    - plan_product -- the managed application package plan product
    - plan_publisher -- the managed application package plan publisher
    - plan_version -- the managed application package plan version
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az managedapp create", locals())


def delete(name, resource_group):
    '''
    Delete a managed application.

    Required Parameters:
    - name -- The name of the managed application.
    - resource_group -- the resource group of the managed application
    '''
    return _call_az("az managedapp delete", locals())


def show(name=None, resource_group=None):
    '''
    

    Optional Parameters:
    - name -- the managed application name
    - resource_group -- the resource group of the managed application
    '''
    return _call_az("az managedapp show", locals())


def list(resource_group=None):
    '''
    List managed applications.

    Optional Parameters:
    - resource_group -- the resource group of the managed application
    '''
    return _call_az("az managedapp list", locals())




from .... pyaz_utils import _call_az

def create(managed_instance, resource_group, display_name=None, object_id=None):
    '''
    Creates a new managed instance Active Directory administrator.

    Required Parameters:
    - managed_instance -- Name of the Azure SQL managed instance.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - display_name -- Display name of the Azure AD administrator user or group.
    - object_id -- The unique ID of the Azure AD administrator.
    '''
    return _call_az("az sql mi ad-admin create", locals())


def list(managed_instance, resource_group):
    '''
    Returns a list of managed instance Active Directory Administrators.

    Required Parameters:
    - managed_instance -- Name of the Azure SQL managed instance.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sql mi ad-admin list", locals())


def delete(managed_instance, resource_group):
    '''
    Deletes an existing managed instance Active Directory Administrator.

    Required Parameters:
    - managed_instance -- Name of the Azure SQL managed instance.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sql mi ad-admin delete", locals())


def update(managed_instance, resource_group, display_name=None, object_id=None):
    '''
    Updates an existing managed instance Active Directory administrator.

    Required Parameters:
    - managed_instance -- Name of the Azure SQL managed instance.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - display_name -- Display name of the Azure AD administrator user or group.
    - object_id -- The unique ID of the Azure AD administrator.
    '''
    return _call_az("az sql mi ad-admin update", locals())




'''
Resource which houses items or applications to be protected.
'''
from ... pyaz_utils import _call_az

def show(name, resource_group, vault_name, backup_management_type=None, use_secondary_region=None):
    '''
    Show details of a container registered to a Recovery services vault.

    Required Parameters:
    - name -- Name of the container. You can use the backup container list command to get the name of a container.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vault_name -- Name of the Recovery services vault.

    Optional Parameters:
    - backup_management_type -- Specify the backup management type. Define how Azure Backup manages the backup of entities within the ARM resource. For eg: AzureWorkloads refers to workloads installed within Azure VMs, AzureStorage refers to entities within Storage account. Required only if friendly name is used as Container name.
    - use_secondary_region -- Use this flag to show container in secondary region.
    '''
    return _call_az("az backup container show", locals())


def list(backup_management_type, resource_group, vault_name, use_secondary_region=None):
    '''
    List containers registered to a Recovery services vault.

    Required Parameters:
    - backup_management_type -- Specify the backup management type. Define how Azure Backup manages the backup of entities within the ARM resource. For eg: AzureWorkloads refers to workloads installed within Azure VMs, AzureStorage refers to entities within Storage account. Required only if friendly name is used as Container name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vault_name -- Name of the Recovery services vault.

    Optional Parameters:
    - use_secondary_region -- Use this flag to list containers in secondary region.
    '''
    return _call_az("az backup container list", locals())


def unregister(container_name, resource_group, vault_name, backup_management_type=None, yes=None):
    '''
    Unregister a Backup Container to make the underlying 'resource' be protected by another vault.

    Required Parameters:
    - container_name -- Name of the backup container. Accepts 'Name' or 'FriendlyName' from the output of az backup container list command. If 'FriendlyName' is passed then BackupManagementType is required.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vault_name -- Name of the Recovery services vault.

    Optional Parameters:
    - backup_management_type -- Specify the backup management type. Define how Azure Backup manages the backup of entities within the ARM resource. For eg: AzureWorkloads refers to workloads installed within Azure VMs, AzureStorage refers to entities within Storage account. Required only if friendly name is used as Container name.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az backup container unregister", locals())


def re_register(container_name, resource_group, vault_name, workload_type, backup_management_type=None, yes=None):
    '''
    Reset the registration details for a given container.

    Required Parameters:
    - container_name -- Name of the backup container. Accepts 'Name' or 'FriendlyName' from the output of az backup container list command. If 'FriendlyName' is passed then BackupManagementType is required.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vault_name -- Name of the Recovery services vault.
    - workload_type -- Specify the type of applications within the Resource which should be discovered and protected by Azure Backup. 

    Optional Parameters:
    - backup_management_type -- Specify the backup management type. Define how Azure Backup manages the backup of entities within the ARM resource. For eg: AzureWorkloads refers to workloads installed within Azure VMs, AzureStorage refers to entities within Storage account. Required only if friendly name is used as Container name.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az backup container re-register", locals())


def register(resource_group, resource_id, vault_name, workload_type, backup_management_type=None):
    '''
    Register a Resource to the given Recovery Services Vault.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_id -- ID of the Azure Resource containing items to be protected by Azure Backup service. Currently, only Azure VM resource IDs are supported.
    - vault_name -- Name of the Recovery services vault.
    - workload_type -- Specify the type of applications within the Resource which should be discovered and protected by Azure Backup. 

    Optional Parameters:
    - backup_management_type -- Specify the backup management type. Define how Azure Backup manages the backup of entities within the ARM resource. For eg: AzureWorkloads refers to workloads installed within Azure VMs, AzureStorage refers to entities within Storage account. Required only if friendly name is used as Container name.
    '''
    return _call_az("az backup container register", locals())




from ... pyaz_utils import _call_az

def list(account_name, asset_name, resource_group):
    '''
    List all the asset filters of an Azure Media Services account.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - asset_name -- The name of the asset.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az ams asset-filter list", locals())


def show(account_name, asset_name, name, resource_group):
    '''
    Show the details of an asset filter.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - asset_name -- The name of the asset.
    - name -- The name of the asset filter.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az ams asset-filter show", locals())


def delete(account_name, asset_name, name, resource_group):
    '''
    Delete an asset filter.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - asset_name -- The name of the asset.
    - name -- The name of the asset filter.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az ams asset-filter delete", locals())


def create(account_name, asset_name, name, resource_group, bitrate=None, end_timestamp=None, first_quality=None, force_end_timestamp=None, live_backoff_duration=None, presentation_window_duration=None, start_timestamp=None, timescale=None, tracks=None):
    '''
    Create an asset filter.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - asset_name -- The name of the asset.
    - name -- The name of the asset filter.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - bitrate -- The first quality bitrate.
    - end_timestamp -- Applies to Video on Demand (VoD).For the Live Streaming presentation, it is silently ignored and applied when the presentation ends and the stream becomes VoD.This is a long value that represents an absolute end point of the presentation, rounded to the closest next GOP start. The unit is the timescale, so an endTimestamp of 1800000000 would be for 3 minutes.Use startTimestamp and endTimestamp to trim the fragments that will be in the playlist (manifest).For example, startTimestamp=40000000 and endTimestamp=100000000 using the default timescale will generate a playlist that contains fragments from between 4 seconds and 10 seconds of the VoD presentation. If a fragment straddles the boundary, the entire fragment will be included in the manifest.
    - first_quality -- The first quality (lowest) bitrate to include in the manifest.
    - force_end_timestamp -- Applies to Live Streaming only. Indicates whether the endTimestamp property must be present. If true, endTimestamp must be specified or a bad request code is returned. Allowed values: false, true.
    - live_backoff_duration -- Applies to Live Streaming only. This value defines the latest live position that a client can seek to. Using this property, you can delay live playback position and create a server-side buffer for players. The unit for this property is timescale (see below). The maximum live back off duration is 300 seconds (3000000000). For example, a value of 2000000000 means that the latest available content is 20 seconds delayed from the real live edge.
    - presentation_window_duration -- Applies to Live Streaming only.Use presentationWindowDuration to apply a sliding window of fragments to include in a playlist.The unit for this property is timescale (see below).For example, set presentationWindowDuration=1200000000 to apply a two-minute sliding window. Media within 2 minutes of the live edge will be included in the playlist. If a fragment straddles the boundary, the entire fragment will be included in the playlist. The minimum presentation window duration is 60 seconds.
    - start_timestamp -- Applies to Video on Demand (VoD) or Live Streaming. This is a long value that represents an absolute start point of the stream. The value gets rounded to the closest next GOP start. The unit is the timescale, so a startTimestamp of 150000000 would be for 15 seconds. Use startTimestamp and endTimestampp to trim the fragments that will be in the playlist (manifest). For example, startTimestamp=40000000 and endTimestamp=100000000 using the default timescale will generate a playlist that contains fragments from between 4 seconds and 10 seconds of the VoD presentation. If a fragment straddles the boundary, the entire fragment will be included in the manifest.
    - timescale -- Applies to all timestamps and durations in a Presentation Time Range, specified as the number of increments in one second.Default is 10000000 - ten million increments in one second, where each increment would be 100 nanoseconds long. For example, if you want to set a startTimestamp at 30 seconds, you would use a value of 300000000 when using the default timescale.
    - tracks -- The JSON representing the track selections. Use @{file} to load from a file. For further information about the JSON structure please refer to swagger documentation on https://docs.microsoft.com/rest/api/media/assetfilters/createorupdate#filtertrackselection
    '''
    return _call_az("az ams asset-filter create", locals())


def update(account_name, asset_name, name, resource_group, add=None, bitrate=None, end_timestamp=None, first_quality=None, force_end_timestamp=None, force_string=None, live_backoff_duration=None, presentation_window_duration=None, remove=None, set=None, start_timestamp=None, timescale=None, tracks=None):
    '''
    Update the details of an asset filter.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - asset_name -- The name of the asset.
    - name -- The name of the asset filter.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - bitrate -- The first quality bitrate.
    - end_timestamp -- Applies to Video on Demand (VoD).For the Live Streaming presentation, it is silently ignored and applied when the presentation ends and the stream becomes VoD.This is a long value that represents an absolute end point of the presentation, rounded to the closest next GOP start. The unit is the timescale, so an endTimestamp of 1800000000 would be for 3 minutes.Use startTimestamp and endTimestamp to trim the fragments that will be in the playlist (manifest).For example, startTimestamp=40000000 and endTimestamp=100000000 using the default timescale will generate a playlist that contains fragments from between 4 seconds and 10 seconds of the VoD presentation. If a fragment straddles the boundary, the entire fragment will be included in the manifest.
    - first_quality -- The first quality (lowest) bitrate to include in the manifest.
    - force_end_timestamp -- Applies to Live Streaming only. Indicates whether the endTimestamp property must be present. If true, endTimestamp must be specified or a bad request code is returned. Allowed values: false, true.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - live_backoff_duration -- Applies to Live Streaming only. This value defines the latest live position that a client can seek to. Using this property, you can delay live playback position and create a server-side buffer for players. The unit for this property is timescale (see below). The maximum live back off duration is 300 seconds (3000000000). For example, a value of 2000000000 means that the latest available content is 20 seconds delayed from the real live edge.
    - presentation_window_duration -- Applies to Live Streaming only.Use presentationWindowDuration to apply a sliding window of fragments to include in a playlist.The unit for this property is timescale (see below).For example, set presentationWindowDuration=1200000000 to apply a two-minute sliding window. Media within 2 minutes of the live edge will be included in the playlist. If a fragment straddles the boundary, the entire fragment will be included in the playlist. The minimum presentation window duration is 60 seconds.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - start_timestamp -- Applies to Video on Demand (VoD) or Live Streaming. This is a long value that represents an absolute start point of the stream. The value gets rounded to the closest next GOP start. The unit is the timescale, so a startTimestamp of 150000000 would be for 15 seconds. Use startTimestamp and endTimestampp to trim the fragments that will be in the playlist (manifest). For example, startTimestamp=40000000 and endTimestamp=100000000 using the default timescale will generate a playlist that contains fragments from between 4 seconds and 10 seconds of the VoD presentation. If a fragment straddles the boundary, the entire fragment will be included in the manifest.
    - timescale -- Applies to all timestamps and durations in a Presentation Time Range, specified as the number of increments in one second.Default is 10000000 - ten million increments in one second, where each increment would be 100 nanoseconds long. For example, if you want to set a startTimestamp at 30 seconds, you would use a value of 300000000 when using the default timescale.
    - tracks -- The JSON representing the track selections. Use @{file} to load from a file. For further information about the JSON structure please refer to swagger documentation on https://docs.microsoft.com/rest/api/media/assetfilters/createorupdate#filtertrackselection
    '''
    return _call_az("az ams asset-filter update", locals())

